@@ -1,10 +1,10 @@
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #
 #  Copyright (c) 2008, Enthought, Inc.
 #  All rights reserved.
 #
 #  This software is provided without warranty under the terms of the BSD
-#  license included in enthought/LICENSE.txt and may be redistributed only
+#  license included in LICENSE.txt and may be redistributed only
 #  under the conditions described in the aforementioned license.  The license
 #  is also available online at http://www.enthought.com/licenses/BSD.txt
 #
@@ -13,15 +13,11 @@
 #  Author: David C. Morrill
 #  Date:   10/21/2004
 #
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 
 """ Defines the color editor factory for the all traits toolkit backends.
 """
 
-#-------------------------------------------------------------------------
-#  Imports:
-#-------------------------------------------------------------------------
-
 
 
 from traits.api import Bool
@@ -35,31 +31,31 @@ from ..view import View
 
 from ..editor_factory import EditorFactory
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #  'ToolkitEditorFactory' class:
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 
 
 class ToolkitEditorFactory(EditorFactory):
     """ Editor factory for color editors.
     """
 
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
     #  Trait definitions:
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
 
-    # Is the underlying color trait mapped?
+    #: Is the underlying color trait mapped?
     mapped = Bool(True)
 
-    # Do we use a native dialog for the popup or the toolkit's?
-    # At present, only affects Qt.
+    #: Do we use a native dialog for the popup or the toolkit's?
+    #: At present, only affects Qt.
     use_native_dialog = Bool(True)
 
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
     #  Traits view definition:
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
 
-    traits_view = View(['mapped{Is value mapped?}', '|[]>'])
+    traits_view = View(["mapped{Is value mapped?}", "|[]>"])
 
 
 # Define the ColorEditor class
@@ -67,7 +63,7 @@ class ToolkitEditorFactory(EditorFactory):
 # in traitsui.<toolkit>.color_editor, and if none is found, the
 # ToolkitEditorFactory declared here is returned.
 def ColorEditor(*args, **traits):
-    """ Returns an instance of the toolkit-specific editor factory declared in
+    r""" Returns an instance of the toolkit-specific editor factory declared in
     traitsui.<toolkit>.color_editor. If such an editor factory
     cannot be located, an instance of the abstract ToolkitEditorFactory
     declared in traitsui.editors.color_editor is returned.
@@ -80,10 +76,8 @@ def ColorEditor(*args, **traits):
     """
 
     try:
-        return toolkit_object(
-            'color_editor:ToolkitEditorFactory', True)(
-            *args, **traits)
+        return toolkit_object("color_editor:ToolkitEditorFactory", True)(
+            *args, **traits
+        )
     except:
         return ToolkitEditorFactory(*args, **traits)
-
-## EOF #######################################################################
