@@ -1,10 +1,10 @@
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #
 #  Copyright (c) 2006, Enthought, Inc.
 #  All rights reserved.
 #
 #  This software is provided without warranty under the terms of the BSD
-#  license included in enthought/LICENSE.txt and may be redistributed only
+#  license included in LICENSE.txt and may be redistributed only
 #  under the conditions described in the aforementioned license.  The license
 #  is also available online at http://www.enthought.com/licenses/BSD.txt
 #
@@ -13,16 +13,17 @@
 #  Written by: Jason Sugg
 #  Date:   03/28/2006
 #
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 
 """ Defines 'pseudo' package that imports all of the traits extras symbols.
 """
 
-#-------------------------------------------------------------------------
-#  Imports:
-#-------------------------------------------------------------------------
 
-from __future__ import absolute_import
 
 from .checkbox_column import CheckboxColumn
+from .edit_column import EditColumn
+from .has_dynamic_views import (
+    DynamicView, DynamicViewSubElement, HasDynamicViews
+)
+from .progress_column import ProgressColumn
 from .saving import CanSaveMixin, SaveHandler
