@@ -3,4 +3,4 @@ from traitsui.toolkit import toolkit_object
 
 # WIP: Currently only supports qt4 backend. API might change without
 # prior notification
-PyMimeData = toolkit_object('clipboard:PyMimeData')
+PyMimeData = toolkit_object("clipboard:PyMimeData")
