@@ -1,4 +1,4 @@
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 # Copyright (c) 2007, Riverbank Computing Limited
 # All rights reserved.
 #
@@ -8,23 +8,16 @@
 
 #
 # Author: Riverbank Computing Limited
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 
 """ Trait definition for a PyQt-based color.
 """
 
-#-------------------------------------------------------------------------
-#  Imports:
-#-------------------------------------------------------------------------
 
 from pyface.qt import QtGui
 
-from traits.api \
-    import Trait, TraitError
+from traits.api import Trait, TraitError
 
-#-------------------------------------------------------------------------
-#  Convert a number into a QColor object:
-#-------------------------------------------------------------------------
 
 
 def convert_to_color(object, name, value):
@@ -47,7 +40,7 @@ def convert_to_color(object, name, value):
     else:
         if isinstance(value, str):
             # Allow for spaces in the string value.
-            value = value.replace(' ', '')
+            value = value.replace(" ", "")
 
         # Let the standard ctors handle the value.
         try:
@@ -60,15 +53,18 @@ def convert_to_color(object, name, value):
 
     return color
 
-convert_to_color.info = ('a string of the form (r,g,b) or (r,g,b,a) where r, '
-                         'g, b, and a are integers from 0 to 255, a QColor '
-                         'instance, a Qt.GlobalColor, an integer which in hex '
-                         'is of the form 0xRRGGBB, a string of the form #RGB, '
-                         '#RRGGBB, #RRRGGGBBB or #RRRRGGGGBBBB')
 
-#-------------------------------------------------------------------------
+convert_to_color.info = (
+    "a string of the form (r,g,b) or (r,g,b,a) where r, "
+    "g, b, and a are integers from 0 to 255, a QColor "
+    "instance, a Qt.GlobalColor, an integer which in hex "
+    "is of the form 0xRRGGBB, a string of the form #RGB, "
+    "#RRGGBB, #RRRGGGBBB or #RRRRGGGGBBBB"
+)
+
+# -------------------------------------------------------------------------
 #  Standard colors:
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 
 # Note that this is slightly different from the wx implementation in that the
 # names do not include spaces and the full set of SVG color keywords is
@@ -77,10 +73,10 @@ standard_colors = {}
 for name in QtGui.QColor.colorNames():
     standard_colors[str(name)] = QtGui.QColor(name)
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #  Callable that returns an instance of the PyQtToolkitEditorFactory for color
 #  editors.
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 
 ### FIXME: We have declared the 'editor' to be a function instead of  the
 # traitsui.qt4.color_editor.ToolkitEditorFactory class, since the
@@ -90,19 +86,30 @@ for name in QtGui.QColor.colorNames():
 
 def get_color_editor(*args, **traits):
     from traitsui.qt4.color_editor import ToolkitEditorFactory
+
     return ToolkitEditorFactory(*args, **traits)
 
-#-------------------------------------------------------------------------
-#  Define PyQt specific color traits:
-#-------------------------------------------------------------------------
 
-
-def PyQtColor(default='white', allow_none=False, **metadata):
+def PyQtColor(default="white", allow_none=False, **metadata):
     """ Defines PyQt-specific color traits.
     """
-    if allow_none:
-        return Trait(default, None, standard_colors, convert_to_color,
-                     editor=get_color_editor, **metadata)
+    if default is None:
+        allow_none = True
 
-    return Trait(default, standard_colors, convert_to_color,
-                 editor=get_color_editor, **metadata)
+    if allow_none:
+        return Trait(
+            default,
+            None,
+            standard_colors,
+            convert_to_color,
+            editor=get_color_editor,
+            **metadata
+        )
+
+    return Trait(
+        default,
+        standard_colors,
+        convert_to_color,
+        editor=get_color_editor,
+        **metadata
+    )
