@@ -1,3 +1,4 @@
+
 from pyface.qt import QtGui, QtCore
 
 
@@ -53,7 +54,9 @@ class RangeSlider(QtGui.QSlider):
             # Only draw the groove for the first slider so it doesn't get drawn
             # on top of the existing ones every time
             if i == 0:
-                opt.subControls = QtGui.QStyle.SC_SliderGroove | QtGui.QStyle.SC_SliderHandle
+                opt.subControls = (
+                    QtGui.QStyle.SC_SliderGroove | QtGui.QStyle.SC_SliderHandle
+                )
             else:
                 opt.subControls = QtGui.QStyle.SC_SliderHandle
 
@@ -69,7 +72,8 @@ class RangeSlider(QtGui.QSlider):
             opt.sliderPosition = value
             opt.sliderValue = value
             style.drawComplexControl(
-                QtGui.QStyle.CC_Slider, opt, painter, self)
+                QtGui.QStyle.CC_Slider, opt, painter, self
+            )
 
     def mousePressEvent(self, event):
         event.accept()
@@ -92,7 +96,8 @@ class RangeSlider(QtGui.QSlider):
             for i, value in enumerate([self._low, self._high]):
                 opt.sliderPosition = value
                 hit = style.hitTestComplexControl(
-                    style.CC_Slider, opt, event.pos(), self)
+                    style.CC_Slider, opt, event.pos(), self
+                )
                 if hit == style.SC_SliderHandle:
                     self.active_slider = i
                     self.pressed_control = hit
@@ -105,7 +110,8 @@ class RangeSlider(QtGui.QSlider):
             if self.active_slider < 0:
                 self.pressed_control = QtGui.QStyle.SC_SliderHandle
                 self.click_offset = self.__pixelPosToRangeValue(
-                    self.__pick(event.pos()))
+                    self.__pick(event.pos())
+                )
                 self.triggerAction(self.SliderMove)
                 self.setRepeatAction(self.SliderNoAction)
         else:
@@ -160,9 +166,11 @@ class RangeSlider(QtGui.QSlider):
         style = QtGui.QApplication.style()
 
         gr = style.subControlRect(
-            style.CC_Slider, opt, style.SC_SliderGroove, self)
+            style.CC_Slider, opt, style.SC_SliderGroove, self
+        )
         sr = style.subControlRect(
-            style.CC_Slider, opt, style.SC_SliderHandle, self)
+            style.CC_Slider, opt, style.SC_SliderHandle, self
+        )
 
         if self.orientation() == QtCore.Qt.Horizontal:
             slider_length = sr.width()
@@ -178,13 +186,16 @@ class RangeSlider(QtGui.QSlider):
             self.maximum(),
             pos - slider_min,
             slider_max - slider_min,
-            opt.upsideDown)
+            opt.upsideDown,
+        )
+
 
 if __name__ == "__main__":
     import sys
 
     def echo(value):
         print(value)
+
     app = QtGui.QApplication(sys.argv)
     slider = RangeSlider()
     slider.setMinimum(0)
