@@ -1,4 +1,4 @@
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 # Copyright (c) 2007, Riverbank Computing Limited
 # All rights reserved.
 #
@@ -8,57 +8,51 @@
 
 #
 # Author: Riverbank Computing Limited
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 
 """ Defines helper functions and classes used to define PyQt-based trait
     editors and trait editor factories.
 """
 
-#-------------------------------------------------------------------------
-#  Imports:
-#-------------------------------------------------------------------------
-
-from __future__ import absolute_import
 import os.path
 
-from pyface.qt import QtCore, QtGui
+from pyface.qt import QtCore, QtGui, is_qt5, qt_api
 from pyface.ui_traits import convert_image
 from traits.api import Enum, CTrait, BaseTraitHandler, TraitError
 
 from traitsui.ui_traits import SequenceTypes
-import six
 
-is_qt5 = QtCore.__version_info__ >= (5,)
 
-#-------------------------------------------------------------------------
-#  Trait definitions:
-#-------------------------------------------------------------------------
 
-# Layout orientation for a control and its associated editor
-Orientation = Enum('horizontal', 'vertical')
+is_pyqt = qt_api in {"pyqt", "pyqt5"}
 
-#-------------------------------------------------------------------------
-#  Convert an image file name to a cached QPixmap:
-#-------------------------------------------------------------------------
+
+#: Layout orientation for a control and its associated editor
+Orientation = Enum("horizontal", "vertical")
+
+#: Dock-related stubs.
+DockStyle = Enum("horizontal", "vertical", "tab", "fixed")
 
 
 def pixmap_cache(name, path=None):
-    """ Return the QPixmap corresponding to a filename. If the filename does not
-        contain a path component, 'path' is used (or if 'path' is not specified,
-        the local 'images' directory is used).
+    """ Convert an image file name to a cached QPixmap
+
+    Returns the QPixmap corresponding to a filename. If the filename does not
+    contain a path component, 'path' is used (or if 'path' is not specified,
+    the local 'images' directory is used).
     """
-    if name[:1] == '@':
-        image = convert_image(name.replace(' ', '_').lower())
+    if name[:1] == "@":
+        image = convert_image(name.replace(" ", "_").lower())
         if image is not None:
             return image.create_image()
 
     name_path, name = os.path.split(name)
-    name = name.replace(' ', '_').lower()
+    name = name.replace(" ", "_").lower()
     if name_path:
         filename = os.path.join(name_path, name)
     else:
         if path is None:
-            filename = os.path.join(os.path.dirname(__file__), 'images', name)
+            filename = os.path.join(os.path.dirname(__file__), "images", name)
         else:
             filename = os.path.join(path, name)
     filename = os.path.abspath(filename)
@@ -75,11 +69,6 @@ def pixmap_cache(name, path=None):
             QtGui.QPixmapCache.insert(filename, pm)
     return pm
 
-#-------------------------------------------------------------------------
-#  Positions a window on the screen with a specified width and height so that
-#  the window completely fits on the screen if possible:
-#-------------------------------------------------------------------------
-
 
 def position_window(window, width=None, height=None, parent=None):
     """ Positions a window on the screen with a specified width and height so
@@ -128,12 +117,9 @@ def position_window(window, width=None, height=None, parent=None):
     y += cdy + fheight
 
     # Position the window (making sure it will fit on the screen).
-    window.move(max(0, min(x, screen_dx - width)),
-                max(0, min(y, screen_dy - height)))
-
-#-------------------------------------------------------------------------
-#  Restores the user preference items for a specified UI:
-#-------------------------------------------------------------------------
+    window.move(
+        max(0, min(x, screen_dx - width)), max(0, min(y, screen_dy - height))
+    )
 
 
 def restore_window(ui):
@@ -143,10 +129,6 @@ def restore_window(ui):
     if prefs is not None:
         ui.control.setGeometry(*prefs)
 
-#-------------------------------------------------------------------------
-#  Saves the user preference items for a specified UI:
-#-------------------------------------------------------------------------
-
 
 def save_window(ui):
     """ Saves the user preference items for a specified UI.
@@ -155,11 +137,6 @@ def save_window(ui):
     ui.save_prefs((geom.x(), geom.y(), geom.width(), geom.height()))
 
 
-#-------------------------------------------------------------------------
-#  'IconButton' class:
-#-------------------------------------------------------------------------
-
-
 class IconButton(QtGui.QPushButton):
     """ The IconButton class is a push button that contains a small image or a
         standard icon provided by the current style.
@@ -177,7 +154,7 @@ class IconButton(QtGui.QPushButton):
         # Get the minimum icon size to use.
         ico_sz = sty.pixelMetric(QtGui.QStyle.PM_ButtonIconSize)
 
-        if isinstance(icon, six.string_types):
+        if isinstance(icon, str):
             pm = pixmap_cache(icon)
 
             # Increase the icon size to accomodate the image if needed.
@@ -202,15 +179,11 @@ class IconButton(QtGui.QPushButton):
 
         self.clicked.connect(slot)
 
-#-------------------------------------------------------------------------
-#  Dock-related stubs.
-#-------------------------------------------------------------------------
 
-DockStyle = Enum('horizontal', 'vertical', 'tab', 'fixed')
+# ------------------------------------------------------------------------
+# Text Rendering helpers
+# ------------------------------------------------------------------------
 
-#-------------------------------------------------------------------------
-#  Text Rendering helpers
-#-------------------------------------------------------------------------
 
 def wrap_text_with_elision(text, font, width, height):
     """ Wrap paragraphs to fit inside a given size, eliding if too long.
