@@ -1,10 +1,10 @@
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 #  Copyright (c) 2009, Enthought, Inc.
 #  All rights reserved.
 #
 #  This software is provided without warranty under the terms of the BSD
-#  license included in enthought/LICENSE.txt and may be redistributed only
+#  license included in LICENSE.txt and may be redistributed only
 #  under the conditions described in the aforementioned license.  The license
 #  is also available online at http://www.enthought.com/licenses/BSD.txt
 #
@@ -13,31 +13,21 @@
 #  Author: Evan Patterson
 #  Date:   08/05/2009
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 
 """ Defines the table model used by the tabular editor.
 """
 
-#-------------------------------------------------------------------------
-#  Imports:
-#-------------------------------------------------------------------------
-
 
 
 from pyface.qt import QtCore, QtGui
 
 from traitsui.ui_traits import SequenceTypes
 
-#-------------------------------------------------------------------------
-#  Constants:
-#-------------------------------------------------------------------------
+
 
 # MIME type for internal table drag/drop operations
-mime_type = 'traits-ui-list-str-editor'
-
-#-------------------------------------------------------------------------
-#  'ListStrModel' class:
-#-------------------------------------------------------------------------
+mime_type = "traits-ui-list-str-editor"
 
 
 class ListStrModel(QtCore.QAbstractListModel):
@@ -51,9 +41,9 @@ class ListStrModel(QtCore.QAbstractListModel):
 
         self._editor = editor
 
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
     #  QAbstractItemModel interface:
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
 
     def rowCount(self, mi):
         """ Reimplemented to return items in the list.
@@ -70,19 +60,21 @@ class ListStrModel(QtCore.QAbstractListModel):
 
         if role == QtCore.Qt.DisplayRole or role == QtCore.Qt.EditRole:
             if editor.is_auto_add(index):
-                text = adapter.get_default_text(editor.object, editor.name,
-                                                index)
+                text = adapter.get_default_text(
+                    editor.object, editor.name, index
+                )
             else:
                 text = adapter.get_text(editor.object, editor.name, index)
-            if role == QtCore.Qt.DisplayRole and text == '':
+            if role == QtCore.Qt.DisplayRole and text == "":
                 # FIXME: This is a hack to make empty strings editable.
-                text = ' '
+                text = " "
             return text
 
         elif role == QtCore.Qt.DecorationRole:
             if editor.is_auto_add(index):
-                image = adapter.get_default_image(editor.object,
-                                                  editor.name, index)
+                image = adapter.get_default_image(
+                    editor.object, editor.name, index
+                )
             else:
                 image = adapter.get_image(editor.object, editor.name, index)
             image = editor.get_image(image)
@@ -92,7 +84,8 @@ class ListStrModel(QtCore.QAbstractListModel):
         elif role == QtCore.Qt.BackgroundRole:
             if editor.is_auto_add(index):
                 color = adapter.get_default_bg_color(
-                    editor.object, editor.name)
+                    editor.object, editor.name
+                )
             else:
                 color = adapter.get_bg_color(editor.object, editor.name, index)
             if color is not None:
@@ -104,11 +97,13 @@ class ListStrModel(QtCore.QAbstractListModel):
 
         elif role == QtCore.Qt.ForegroundRole:
             if editor.is_auto_add(index):
-                color = adapter.get_default_text_color(editor.object,
-                                                       editor.name)
+                color = adapter.get_default_text_color(
+                    editor.object, editor.name
+                )
             else:
-                color = adapter.get_text_color(editor.object,
-                                               editor.name, index)
+                color = adapter.get_text_color(
+                    editor.object, editor.name, index
+                )
             if color is not None:
                 if isinstance(color, SequenceTypes):
                     q_color = QtGui.QColor(*color)
@@ -145,12 +140,19 @@ class ListStrModel(QtCore.QAbstractListModel):
 
         flags = QtCore.Qt.ItemIsSelectable | QtCore.Qt.ItemIsEnabled
 
-        if (editor.factory.editable and 'edit' in editor.factory.operations and
-                editor.adapter.get_can_edit(editor.object, editor.name, index)):
+        if (
+            editor.factory.editable
+            and "edit" in editor.factory.operations
+            and editor.adapter.get_can_edit(editor.object, editor.name, index)
+        ):
             flags |= QtCore.Qt.ItemIsEditable
 
-        if (editor.factory.editable and 'move' in editor.factory.operations and
-                editor.adapter.get_drag(editor.object, editor.name, index) is not None):
+        if (
+            editor.factory.editable
+            and "move" in editor.factory.operations
+            and editor.adapter.get_drag(editor.object, editor.name, index)
+            is not None
+        ):
             flags |= QtCore.Qt.ItemIsDragEnabled | QtCore.Qt.ItemIsDropEnabled
 
         return flags
@@ -158,7 +160,10 @@ class ListStrModel(QtCore.QAbstractListModel):
     def headerData(self, section, orientation, role):
         """ Reimplemented to return title for vertical header data.
         """
-        if orientation != QtCore.Qt.Horizontal or role != QtCore.Qt.DisplayRole:
+        if (
+            orientation != QtCore.Qt.Horizontal
+            or role != QtCore.Qt.DisplayRole
+        ):
             return None
 
         return self._editor.title
@@ -174,7 +179,8 @@ class ListStrModel(QtCore.QAbstractListModel):
             obj = adapter.get_default_value(editor.object, editor.name)
         self.beginInsertRows(parent, row, row)
         editor.callx(
-            editor.adapter.insert, editor.object, editor.name, row, obj)
+            editor.adapter.insert, editor.object, editor.name, row, obj
+        )
         self.endInsertRows()
         return True
 
@@ -188,11 +194,8 @@ class ListStrModel(QtCore.QAbstractListModel):
         for i in range(count):
             value = adapter.get_default_value(editor.object, editor.name)
             editor.callx(
-                adapter.insert,
-                editor.object,
-                editor.name,
-                row,
-                value)
+                adapter.insert, editor.object, editor.name, row, value
+            )
         self.endInsertRows()
         return True
 
@@ -220,10 +223,10 @@ class ListStrModel(QtCore.QAbstractListModel):
             current selection.
         """
         mime_data = QtCore.QMimeData()
-        rows = list(set([index.row() for index in indexes]))
-        data = QtCore.QByteArray(str(rows[0]).encode('utf8'))
+        rows = list({index.row() for index in indexes})
+        data = QtCore.QByteArray(str(rows[0]).encode("utf8"))
         for row in rows[1:]:
-            data.append((' %i' % row).encode('utf8'))
+            data.append((" %i" % row).encode("utf8"))
         mime_data.setData(mime_type, data)
         return mime_data
 
@@ -237,7 +240,7 @@ class ListStrModel(QtCore.QAbstractListModel):
         if data.isNull():
             return False
 
-        current_rows = [int(s) for s in data.data().decode('utf8').split(' ')]
+        current_rows = [int(s) for s in data.data().decode("utf8").split(" ")]
         self.moveRows(current_rows, parent.row())
         return True
 
@@ -246,9 +249,9 @@ class ListStrModel(QtCore.QAbstractListModel):
         """
         return QtCore.Qt.MoveAction
 
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
     #  ListStrModel interface:
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
 
     def moveRow(self, old_row, new_row):
         """ Convenience method to move a single row.
@@ -287,8 +290,9 @@ class ListStrModel(QtCore.QAbstractListModel):
         # Update the selection for the new location.
         if editor.factory.multi_select:
             editor.setx(multi_selected=objects)
-            editor.multi_selected_indices = list(range(
-                new_row, new_row + len(objects)))
+            editor.multi_selected_indices = list(
+                range(new_row, new_row + len(objects))
+            )
         else:
             editor.setx(selected=objects[0])
             editor.selected_index = new_row
