@@ -1,34 +1,31 @@
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #
 #  Copyright (c) 2009, Enthought, Inc.
 #  All rights reserved.
 #
 #  This software is provided without warranty under the terms of the BSD
-#  license included in enthought/LICENSE.txt and may be redistributed only
+#  license included in LICENSE.txt and may be redistributed only
 #  under the conditions described in the aforementioned license.  The license
 #  is also available online at http://www.enthought.com/licenses/BSD.txt
 #
 #  Thanks for using Enthought open source!
 #
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 
 """ Trait definition for an RGB-based color, which is a tuple of the form
     (*red*, *green*, *blue*), where *red*, *green* and *blue* are floats in the
     range from 0.0 to 1.0.
 """
 
-#-------------------------------------------------------------------------
-#  Imports:
-#-------------------------------------------------------------------------
 
 from traits.api import Trait, TraitError
 from traits.trait_base import SequenceTypes
 
 from traitsui.qt4.color_trait import standard_colors
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #  Convert a number into an RGB tuple:
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 
 
 def range_check(value):
@@ -48,34 +45,38 @@ def convert_to_color(object, name, value):
         TraitError if that is not possible.
     """
     if isinstance(value, SequenceTypes) and len(value) == 3:
-        return (range_check(value[0]),
-                range_check(value[1]),
-                range_check(value[2]))
+        return (
+            range_check(value[0]),
+            range_check(value[1]),
+            range_check(value[2]),
+        )
     if isinstance(value, int):
-        return ((value / 0x10000) / 255.0,
-                ((value / 0x100) & 0xFF) / 255.0,
-                (value & 0xFF) / 255.0)
+        return (
+            (value / 0x10000) / 255.0,
+            ((value / 0x100) & 0xFF) / 255.0,
+            (value & 0xFF) / 255.0,
+        )
     raise TraitError
 
-convert_to_color.info = (
-    'a tuple of the form (r,g,b), where r, g, and b '
-    'are floats in the range from 0.0 to 1.0, or an integer which in hex is of '
-    'the form 0xRRGGBB, where RR is red, GG is green, and BB is blue')
 
-#-------------------------------------------------------------------------
+convert_to_color.info = (
+    "a tuple of the form (r,g,b), where r, g, and b "
+    "are floats in the range from 0.0 to 1.0, or an integer which in hex is of "
+    "the form 0xRRGGBB, where RR is red, GG is green, and BB is blue"
+)
+
+# -------------------------------------------------------------------------
 #  Standard colors:
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 
 # RGB versions of standard colors:
 rgb_standard_colors = {}
-for name, color in list(standard_colors.items()):
-    rgb_standard_colors[name] = (color.redF(),
-                                 color.greenF(),
-                                 color.blueF())
+for name, color in standard_colors.items():
+    rgb_standard_colors[name] = (color.redF(), color.greenF(), color.blueF())
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #  Define wxPython specific color traits:
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 
 ### Note: Declare the editor to be a function which returns the RGBColorEditor
 # class from traits ui to avoid circular import issues. For backwards
@@ -88,8 +89,11 @@ for name, color in list(standard_colors.items()):
 
 def get_rgb_color_editor(*args, **traits):
     from .rgb_color_editor import ToolkitEditorFactory
+
     return ToolkitEditorFactory(*args, **traits)
 
+
 # Trait whose value must be an RGB color:
-RGBColor = Trait('white', convert_to_color, rgb_standard_colors,
-                 editor=get_rgb_color_editor)
+RGBColor = Trait(
+    "white", convert_to_color, rgb_standard_colors, editor=get_rgb_color_editor
+)
