@@ -1,4 +1,4 @@
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 # Copyright (c) 2007, Riverbank Computing Limited
 # All rights reserved.
 #
@@ -8,35 +8,25 @@
 
 #
 # Author: Riverbank Computing Limited
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 
 """ Defines the set editors for the PyQt user interface toolkit.
 """
 
-#-------------------------------------------------------------------------
-#  Imports:
-#-------------------------------------------------------------------------
 
 from pyface.qt import QtCore, QtGui
 
 # FIXME: ToolkitEditorFactory is a proxy class defined here just for backward
 # compatibility. The class has been moved to the
 # traitsui.editors.set_editor file.
-from traitsui.editors.set_editor \
-    import ToolkitEditorFactory
+from traitsui.editors.set_editor import ToolkitEditorFactory
 
-from traitsui.helper \
-    import enum_values_changed
+from traitsui.helper import enum_values_changed
 
-from .editor \
-    import Editor
+from .editor import Editor
 
-from traits.api \
-    import Instance, Property
+from traits.api import Instance, Property
 
-#-------------------------------------------------------------------------
-#  'SimpleEditor' class:
-#-------------------------------------------------------------------------
 
 
 class SimpleEditor(Editor):
@@ -49,30 +39,25 @@ class SimpleEditor(Editor):
     selected item up or down in right-side list box.
     """
 
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
     #  Trait definitions:
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
 
-    # The top level QLayout for the editor:
+    #: The top level QLayout for the editor:
     root_layout = Instance(QtGui.QLayout)
 
-    # Current set of enumeration names:
-    names = Property
+    #: Current set of enumeration names:
+    names = Property()
 
-    # Current mapping from names to values:
-    mapping = Property
+    #: Current mapping from names to values:
+    mapping = Property()
 
-    # Current inverse mapping from values to names:
-    inverse_mapping = Property
+    #: Current inverse mapping from values to names:
+    inverse_mapping = Property()
 
-    # Is set editor scrollable? This value overrides the default.
+    #: Is set editor scrollable? This value overrides the default.
     scrollable = True
 
-    #-------------------------------------------------------------------------
-    #  Finishes initializing the editor by creating the underlying toolkit
-    #  widget:
-    #-------------------------------------------------------------------------
-
     def init(self, parent):
         """ Finishes initializing the editor by creating the underlying toolkit
             widget.
@@ -82,52 +67,55 @@ class SimpleEditor(Editor):
         self.root_layout.setContentsMargins(0, 0, 0, 0)
 
         factory = self.factory
-        if factory.name != '':
-            self._object, self._name, self._value = \
-                self.parse_extended_name(factory.name)
+        if factory.name != "":
+            self._object, self._name, self._value = self.parse_extended_name(
+                factory.name
+            )
             self.values_changed()
-            self._object.on_trait_change(self._values_changed,
-                                         self._name, dispatch='ui')
+            self._object.on_trait_change(
+                self._values_changed, self._name, dispatch="ui"
+            )
         else:
-            factory.on_trait_change(self.update_editor, 'values_modified',
-                                    dispatch='ui')
+            factory.on_trait_change(
+                self.update_editor, "values_modified", dispatch="ui"
+            )
 
         blayout = QtGui.QVBoxLayout()
 
-        self._unused = self._create_listbox(0, self._on_unused, self._on_use,
-                                            factory.left_column_title)
+        self._unused = self._create_listbox(
+            0, self._on_unused, self._on_use, factory.left_column_title
+        )
 
         self._use_all = self._unuse_all = self._up = self._down = None
 
         if factory.can_move_all:
-            self._use_all = self._create_button('>>', blayout,
-                                                self._on_use_all)
+            self._use_all = self._create_button(
+                ">>", blayout, self._on_use_all
+            )
 
-        self._use = self._create_button('>', blayout, self._on_use)
-        self._unuse = self._create_button('<', blayout, self._on_unuse)
+        self._use = self._create_button(">", blayout, self._on_use)
+        self._unuse = self._create_button("<", blayout, self._on_unuse)
 
         if factory.can_move_all:
-            self._unuse_all = self._create_button('<<', blayout,
-                                                  self._on_unuse_all)
+            self._unuse_all = self._create_button(
+                "<<", blayout, self._on_unuse_all
+            )
 
         if factory.ordered:
-            self._up = self._create_button('Move Up', blayout, self._on_up)
-            self._down = self._create_button('Move Down', blayout,
-                                             self._on_down)
+            self._up = self._create_button("Move Up", blayout, self._on_up)
+            self._down = self._create_button(
+                "Move Down", blayout, self._on_down
+            )
 
         self.root_layout.addLayout(blayout, 1, 1, QtCore.Qt.AlignCenter)
 
-        self._used = self._create_listbox(2, self._on_value, self._on_unuse,
-                                          factory.right_column_title)
+        self._used = self._create_listbox(
+            2, self._on_value, self._on_unuse, factory.right_column_title
+        )
 
         self.context_object.on_trait_change(
-            self.update_editor,
-            self.extended_name + '_items?',
-            dispatch='ui')
-
-    #-------------------------------------------------------------------------
-    #  Gets the current set of enumeration names:
-    #-------------------------------------------------------------------------
+            self.update_editor, self.extended_name + "_items?", dispatch="ui"
+        )
 
     def _get_names(self):
         """ Gets the current set of enumeration names.
@@ -137,10 +125,6 @@ class SimpleEditor(Editor):
 
         return self._names
 
-    #-------------------------------------------------------------------------
-    #  Gets the current mapping:
-    #-------------------------------------------------------------------------
-
     def _get_mapping(self):
         """ Gets the current mapping.
         """
@@ -149,10 +133,6 @@ class SimpleEditor(Editor):
 
         return self._mapping
 
-    #-------------------------------------------------------------------------
-    #  Gets the current inverse mapping:
-    #-------------------------------------------------------------------------
-
     def _get_inverse_mapping(self):
         """ Gets the current inverse mapping.
         """
@@ -161,10 +141,6 @@ class SimpleEditor(Editor):
 
         return self._inverse_mapping
 
-    #-------------------------------------------------------------------------
-    #  Creates a list box:
-    #-------------------------------------------------------------------------
-
     def _create_listbox(self, col, handler1, handler2, title):
         """Creates a list box.
         """
@@ -186,10 +162,6 @@ class SimpleEditor(Editor):
 
         return list
 
-    #-------------------------------------------------------------------------
-    #  Creates a button:
-    #-------------------------------------------------------------------------
-
     def _create_button(self, label, layout, handler):
         """ Creates a button.
         """
@@ -198,19 +170,12 @@ class SimpleEditor(Editor):
         layout.addWidget(button)
         return button
 
-    #-------------------------------------------------------------------------
-    #  Recomputes the cached data based on the underlying enumeration model:
-    #-------------------------------------------------------------------------
-
     def values_changed(self):
         """ Recomputes the cached data based on the underlying enumeration model.
         """
-        self._names, self._mapping, self._inverse_mapping = \
-            enum_values_changed(self._value(), self.string_value)
-
-    #-------------------------------------------------------------------------
-    #  Handles the underlying object model's enumeration set being changed:
-    #-------------------------------------------------------------------------
+        self._names, self._mapping, self._inverse_mapping = enum_values_changed(
+            self._value(), self.string_value
+        )
 
     def _values_changed(self):
         """ Handles the underlying object model's enumeration set being changed.
@@ -218,10 +183,6 @@ class SimpleEditor(Editor):
         self.values_changed()
         self.update_editor()
 
-    #-------------------------------------------------------------------------
-    #  Updates the editor when the object trait changes external to the editor:
-    #-------------------------------------------------------------------------
-
     def update_editor(self):
         """ Updates the editor when the object trait changes externally to the
             editor.
@@ -290,40 +251,29 @@ class SimpleEditor(Editor):
         self._check_up_down()
         self._check_left_right()
 
-    #-------------------------------------------------------------------------
-    #  Disposes of the contents of an editor:
-    #-------------------------------------------------------------------------
-
     def dispose(self):
         """ Disposes of the contents of an editor.
         """
         if self._object is not None:
-            self._object.on_trait_change(self._values_changed,
-                                         self._name, remove=True)
+            self._object.on_trait_change(
+                self._values_changed, self._name, remove=True
+            )
         else:
-            self.factory.on_trait_change(self.update_editor,
-                                         'values_modified', remove=True)
+            self.factory.on_trait_change(
+                self.update_editor, "values_modified", remove=True
+            )
 
         self.context_object.on_trait_change(
-            self.update_editor,
-            self.extended_name + '_items?',
-            remove=True)
+            self.update_editor, self.extended_name + "_items?", remove=True
+        )
 
         super(SimpleEditor, self).dispose()
 
-    #-------------------------------------------------------------------------
-    #  Returns the editor's control for indicating error status:
-    #-------------------------------------------------------------------------
-
     def get_error_control(self):
         """ Returns the editor's control for indicating error status.
         """
         return [self._unused, self._used]
 
-    #-------------------------------------------------------------------------
-    #  Event handlers:
-    #-------------------------------------------------------------------------
-
     def _on_value(self):
         if not self.factory.ordered:
             self._unused.clearSelection()
@@ -338,19 +288,23 @@ class SimpleEditor(Editor):
 
     def _on_use(self):
         self._unused_items, self.value = self._transfer_items(
-            self._unused, self._used, self._unused_items, self.value)
+            self._unused, self._used, self._unused_items, self.value
+        )
 
     def _on_unuse(self):
         self.value, self._unused_items = self._transfer_items(
-            self._used, self._unused, self.value, self._unused_items)
+            self._used, self._unused, self.value, self._unused_items
+        )
 
     def _on_use_all(self):
         self._unused_items, self.value = self._transfer_all(
-            self._unused, self._used, self._unused_items, self.value)
+            self._unused, self._used, self._unused_items, self.value
+        )
 
     def _on_unuse_all(self):
         self.value, self._unused_items = self._transfer_all(
-            self._used, self._unused, self.value, self._unused_items)
+            self._used, self._unused, self.value, self._unused_items
+        )
 
     def _on_up(self):
         self._move_item(-1)
@@ -358,14 +312,6 @@ class SimpleEditor(Editor):
     def _on_down(self):
         self._move_item(1)
 
-    #-------------------------------------------------------------------------
-    #  Private methods:
-    #-------------------------------------------------------------------------
-
-    #-------------------------------------------------------------------------
-    #  Transfers all items from one list to another:
-    #-------------------------------------------------------------------------
-
     def _transfer_all(self, list_from, list_to, values_from, values_to):
         """ Transfers all items from one list to another.
         """
@@ -377,7 +323,8 @@ class SimpleEditor(Editor):
             index_to = list_to.count()
             list_from.item(0).setSelected(True)
             list_to.insertItems(
-                index_to, self._get_selected_strings(list_from))
+                index_to, self._get_selected_strings(list_from)
+            )
             list_from.takeItem(0)
             values_to.append(values_from[0])
             del values_from[0]
@@ -388,10 +335,6 @@ class SimpleEditor(Editor):
 
         return (values_from, values_to)
 
-    #-------------------------------------------------------------------------
-    #  Transfers the selected item from one list to another:
-    #-------------------------------------------------------------------------
-
     def _transfer_items(self, list_from, list_to, values_from, values_to):
         """ Transfers the selected item from one list to another.
         """
@@ -425,7 +368,9 @@ class SimpleEditor(Editor):
             # If right list is ordered, keep moved items selected:
             if self.factory.ordered:
                 items = list_to.findItems(
-                    item_label, QtCore.Qt.MatchFixedString | QtCore.Qt.MatchCaseSensitive)
+                    item_label,
+                    QtCore.Qt.MatchFixedString | QtCore.Qt.MatchCaseSensitive,
+                )
                 if items:
                     items[0].setSelected(True)
 
@@ -441,10 +386,6 @@ class SimpleEditor(Editor):
 
         return (values_from, values_to)
 
-    #-------------------------------------------------------------------------
-    #  Moves an item up or down with the 'used' list:
-    #-------------------------------------------------------------------------
-
     def _move_item(self, direction):
         """ Moves an item up or down within the "used" list.
         """
@@ -467,54 +408,55 @@ class SimpleEditor(Editor):
         else:
             index = index_from
             values = [value[index_to], value[index_from]]
-        self.value = value[: index] + values + value[index + 2:]
-    #-------------------------------------------------------------------------
-    #  Sets the proper enable state for the up and down buttons:
-    #-------------------------------------------------------------------------
+        self.value = value[:index] + values + value[index + 2 :]
 
     def _check_up_down(self):
         """ Sets the proper enabled state for the up and down buttons.
         """
         if self.factory.ordered:
             selected = self._used.selectedItems()
-            self._up.setEnabled(len(selected) == 1 and
-                                selected[0] is not self._used.item(0))
+            self._up.setEnabled(
+                len(selected) == 1 and selected[0] is not self._used.item(0)
+            )
             self._down.setEnabled(
-                len(selected) == 1 and selected[0] is not self._used.item(
-                    self._used.count() - 1))
-
-    #-------------------------------------------------------------------------
-    #  Sets the proper enable state for the left and right buttons:
-    #-------------------------------------------------------------------------
+                len(selected) == 1
+                and selected[0] is not self._used.item(self._used.count() - 1)
+            )
 
     def _check_left_right(self):
         """ Sets the proper enabled state for the left and right buttons.
         """
-        self._use.setEnabled(self._unused.count() > 0 and
-                             self._get_first_selection(self._unused) >= 0)
-        self._unuse.setEnabled(self._used.count() > 0 and
-                               self._get_first_selection(self._used) >= 0)
+        self._use.setEnabled(
+            self._unused.count() > 0
+            and self._get_first_selection(self._unused) >= 0
+        )
+        self._unuse.setEnabled(
+            self._used.count() > 0
+            and self._get_first_selection(self._used) >= 0
+        )
 
         if self.factory.can_move_all:
             self._use_all.setEnabled(
-                self._unused.count() > 0 and self._get_first_selection(
-                    self._unused) >= 0)
+                self._unused.count() > 0
+                and self._get_first_selection(self._unused) >= 0
+            )
             self._unuse_all.setEnabled(
-                self._used.count() > 0 and self._get_first_selection(
-                    self._used) >= 0)
+                self._used.count() > 0
+                and self._get_first_selection(self._used) >= 0
+            )
 
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
     # Returns a list of the selected strings in the listbox
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
 
     def _get_selected_strings(self, listbox):
         """ Returns a list of the selected strings in the given *listbox*.
         """
         return [str(itm.text()) for itm in listbox.selectedItems()]
 
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
     # Returns the index of the first (or only) selected item.
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
 
     def _get_first_selection(self, listbox):
         """ Returns the index of the first (or only) selected item.
