@@ -1,10 +1,10 @@
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 #  Copyright (c) 2009, Enthought, Inc.
 #  All rights reserved.
 #
 #  This software is provided without warranty under the terms of the BSD
-#  license included in enthought/LICENSE.txt and may be redistributed only
+#  license included in LICENSE.txt and may be redistributed only
 #  under the conditions described in the aforementioned license.  The license
 #  is also available online at http://www.enthought.com/licenses/BSD.txt
 #
@@ -13,42 +13,31 @@
 #  Author: Evan Patterson
 #  Date:   06/22/2009
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 
 """ Defines the table model used by the tabular editor.
 """
 
-#-------------------------------------------------------------------------
-#  Imports:
-#-------------------------------------------------------------------------
 
-from __future__ import absolute_import, unicode_literals
 
-import six
+
 
 from pyface.qt import QtCore, QtGui
 
 from traitsui.ui_traits import SequenceTypes
 from .clipboard import PyMimeData
 
-#-------------------------------------------------------------------------
-#  Constants:
-#-------------------------------------------------------------------------
 
 # Mapping for trait alignment values to qt4 alignment values:
 alignment_map = {
-    'left': QtCore.Qt.AlignLeft,
-    'right': QtCore.Qt.AlignRight,
-    'center': QtCore.Qt.AlignHCenter,
-    'justify': QtCore.Qt.AlignJustify
+    "left": QtCore.Qt.AlignLeft,
+    "right": QtCore.Qt.AlignRight,
+    "center": QtCore.Qt.AlignHCenter,
+    "justify": QtCore.Qt.AlignJustify,
 }
 
 # MIME type for internal table drag/drop operations
-tabular_mime_type = 'traits-ui-tabular-editor'
-
-#-------------------------------------------------------------------------
-#  'TabularModel' class:
-#-------------------------------------------------------------------------
+tabular_mime_type = "traits-ui-tabular-editor"
 
 
 class TabularModel(QtCore.QAbstractTableModel):
@@ -61,9 +50,9 @@ class TabularModel(QtCore.QAbstractTableModel):
 
         self._editor = editor
 
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
     #  QAbstractItemModel interface:
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
 
     def data(self, mi, role):
         """ Reimplemented to return the data.
@@ -78,8 +67,8 @@ class TabularModel(QtCore.QAbstractTableModel):
 
         elif role == QtCore.Qt.DecorationRole:
             image = editor._get_image(
-                adapter.get_image(
-                    obj, name, row, column))
+                adapter.get_image(obj, name, row, column)
+            )
             if image is not None:
                 return image
 
@@ -148,19 +137,26 @@ class TabularModel(QtCore.QAbstractTableModel):
 
         # If the adapter defines get_can_edit_cell(), use it to determine
         # editability over the row-wise get_can_edit().
-        if (editor.factory.editable and 'edit' in editor.factory.operations and
-                hasattr(editor.adapter, 'get_can_edit_cell')):
-            if editor.adapter.get_can_edit_cell(editor.object, editor.name,
-                                                row, column):
+        if (
+            editor.factory.editable
+            and "edit" in editor.factory.operations
+            and hasattr(editor.adapter, "get_can_edit_cell")
+        ):
+            if editor.adapter.get_can_edit_cell(
+                editor.object, editor.name, row, column
+            ):
                 flags |= QtCore.Qt.ItemIsEditable
-        elif (editor.factory.editable and 'edit' in editor.factory.operations and
-                editor.adapter.get_can_edit(editor.object, editor.name, row)):
+        elif (
+            editor.factory.editable
+            and "edit" in editor.factory.operations
+            and editor.adapter.get_can_edit(editor.object, editor.name, row)
+        ):
             flags |= QtCore.Qt.ItemIsEditable
 
-        if editor.adapter.get_drag(
-                editor.object,
-                editor.name,
-                row) is not None:
+        if (
+            editor.adapter.get_drag(editor.object, editor.name, row)
+            is not None
+        ):
             flags |= QtCore.Qt.ItemIsDragEnabled
 
         if editor.factory.editable:
@@ -207,11 +203,8 @@ class TabularModel(QtCore.QAbstractTableModel):
             obj = adapter.get_default_value(editor.object, editor.name)
         self.beginInsertRows(parent, row, row)
         editor.callx(
-            editor.adapter.insert,
-            editor.object,
-            editor.name,
-            row,
-            obj)
+            editor.adapter.insert, editor.object, editor.name, row, obj
+        )
         self.endInsertRows()
         return True
 
@@ -225,11 +218,8 @@ class TabularModel(QtCore.QAbstractTableModel):
         for i in range(count):
             value = adapter.get_default_value(editor.object, editor.name)
             editor.callx(
-                adapter.insert,
-                editor.object,
-                editor.name,
-                row,
-                value)
+                adapter.insert, editor.object, editor.name, row, value
+            )
         self.endInsertRows()
         return True
 
@@ -247,7 +237,7 @@ class TabularModel(QtCore.QAbstractTableModel):
         if not editor.factory.multi_select:
             editor.selected_row = row if row < n else row - 1
         else:
-            #FIXME: what should the selection be?
+            # FIXME: what should the selection be?
             editor.multi_selected_rows = []
         return True
 
@@ -255,21 +245,27 @@ class TabularModel(QtCore.QAbstractTableModel):
         """ Reimplemented to expose our internal MIME type for drag and drop
             operations.
         """
-        return [tabular_mime_type, PyMimeData.MIME_TYPE,
-                PyMimeData.NOPICKLE_MIME_TYPE]
+        return [
+            tabular_mime_type,
+            PyMimeData.MIME_TYPE,
+            PyMimeData.NOPICKLE_MIME_TYPE,
+        ]
 
     def mimeData(self, indexes):
         """ Reimplemented to generate MIME data containing the rows of the
             current selection.
         """
         rows = sorted({index.row() for index in indexes})
-        items = [self._editor.adapter.get_drag(
-            self._editor.object, self._editor.name, row)
-            for row in rows]
+        items = [
+            self._editor.adapter.get_drag(
+                self._editor.object, self._editor.name, row
+            )
+            for row in rows
+        ]
         mime_data = PyMimeData.coerce(items)
-        data = QtCore.QByteArray(six.text_type(id(self)).encode('utf8'))
+        data = QtCore.QByteArray(str(id(self)).encode("utf8"))
         for row in rows:
-            data.append((' %i' % row).encode('utf8'))
+            data.append((" %i" % row).encode("utf8"))
         mime_data.setData(tabular_mime_type, data)
         return mime_data
 
@@ -282,7 +278,9 @@ class TabularModel(QtCore.QAbstractTableModel):
         # this is a drag from a tabular model
         data = mime_data.data(tabular_mime_type)
         if not data.isNull() and action == QtCore.Qt.MoveAction:
-            id_and_rows = [int(s) for s in data.data().decode('utf8').split(' ')]
+            id_and_rows = [
+                int(s) for s in data.data().decode("utf8").split(" ")
+            ]
             table_id = id_and_rows[0]
             # is it from ourself?
             if table_id == id(self):
@@ -305,8 +303,9 @@ class TabularModel(QtCore.QAbstractTableModel):
             if row == -1 and adapter.len(object, name) == 0:
                 # if empty list, target is after end of list
                 row = 0
-            if all(adapter.get_can_drop(object, name, row, item)
-                   for item in data):
+            if all(
+                adapter.get_can_drop(object, name, row, item) for item in data
+            ):
                 for item in reversed(data):
                     self.dropItem(item, row)
                 return True
@@ -317,9 +316,9 @@ class TabularModel(QtCore.QAbstractTableModel):
         """
         return QtCore.Qt.MoveAction | QtCore.Qt.CopyAction
 
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
     #  TabularModel interface:
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
 
     def dropItem(self, item, row):
         """ Handle a Python object being dropped onto a row """
@@ -329,7 +328,7 @@ class TabularModel(QtCore.QAbstractTableModel):
         adapter = editor.adapter
         destination = adapter.get_dropped(object, name, row, item)
 
-        if destination == 'after':
+        if destination == "after":
             row += 1
 
         adapter.insert(object, name, row, item)
@@ -371,7 +370,9 @@ class TabularModel(QtCore.QAbstractTableModel):
         # Update the selection for the new location.
         if editor.factory.multi_select:
             editor.setx(multi_selected=objects)
-            editor.multi_selected_rows = list(range(new_row, new_row + len(objects)))
+            editor.multi_selected_rows = list(
+                range(new_row, new_row + len(objects))
+            )
         else:
             editor.setx(selected=objects[0])
             editor.selected_row = new_row
