@@ -1,4 +1,4 @@
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 # Copyright (c) 2008, Riverbank Computing Limited
 # All rights reserved.
 #
@@ -8,11 +8,7 @@
 
 #
 # Author: Riverbank Computing Limited
-#------------------------------------------------------------------------------
-
-#-------------------------------------------------------------------------
-#  Imports:
-#-------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 
 
 
@@ -29,12 +25,6 @@ from ..editors.title_editor import TitleEditor
 
 
 class SimpleEditor(Editor):
-
-    #-------------------------------------------------------------------------
-    #  Finishes initializing the editor by creating the underlying toolkit
-    #  widget:
-    #-------------------------------------------------------------------------
-
     def init(self, parent):
         """ Finishes initializing the editor by creating the underlying toolkit
             widget.
@@ -42,21 +32,20 @@ class SimpleEditor(Editor):
         self._control = HeadingText(None)
         self.control = self._control.control
         if self.factory.allow_selection:
-            flags = (self.control.textInteractionFlags() |
-                     QtCore.Qt.TextSelectableByMouse)
+            flags = (
+                self.control.textInteractionFlags()
+                | QtCore.Qt.TextSelectableByMouse
+            )
             self.control.setTextInteractionFlags(flags)
         self.set_tooltip()
 
-    #-------------------------------------------------------------------------
-    #  Updates the editor when the object trait changes external to the editor:
-    #-------------------------------------------------------------------------
-
     def update_editor(self):
         """ Updates the editor when the object trait changes external to the
             editor.
         """
         self._control.text = self.str_value
 
+
 CustomEditor = SimpleEditor
 ReadonlyEditor = SimpleEditor
 TextEditor = SimpleEditor
