@@ -1,4 +1,4 @@
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 # Copyright (c) 2007, Riverbank Computing Limited
 # All rights reserved.
 #
@@ -8,28 +8,25 @@
 
 #
 # Author: Riverbank Computing Limited
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 
 """ Defines the tuple editor for the PyQt user interface toolkit.
 """
 
-#-------------------------------------------------------------------------
-#  Imports:
-#-------------------------------------------------------------------------
-
 
 # FIXME: ToolkitEditorFactory is a proxy class defined here just for backward
 # compatibility. The class has been moved to the
 # traitsui.editors.tuple_editor file.
-from traitsui.editors.tuple_editor \
-    import SimpleEditor as BaseSimpleEditor, ToolkitEditorFactory
+from traitsui.editors.tuple_editor import (
+    SimpleEditor as BaseSimpleEditor,
+    ToolkitEditorFactory,
+)
 
-from .editor \
-    import Editor
+from .editor import Editor
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #  'SimpleEditor' class:
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 
 
 class SimpleEditor(BaseSimpleEditor, Editor):
@@ -38,4 +35,5 @@ class SimpleEditor(BaseSimpleEditor, Editor):
     The editor displays an editor for each of the fields in the tuple, based on
     the type of each field.
     """
+
     pass
