@@ -1,10 +1,10 @@
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #
 #  Copyright (c) 2005, Enthought, Inc.
 #  All rights reserved.
 #
 #  This software is provided without warranty under the terms of the BSD
-#  license included in enthought/LICENSE.txt and may be redistributed only
+#  license included in LICENSE.txt and may be redistributed only
 #  under the conditions described in the aforementioned license.  The license
 #  is also available online at http://www.enthought.com/licenses/BSD.txt
 #
@@ -13,72 +13,93 @@
 #  Author: David C. Morrill
 #  Date:   10/14/2004
 #
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 
 """ Defines common traits used within the traits.ui package.
 """
 
-#-------------------------------------------------------------------------
-#  Imports:
-#-------------------------------------------------------------------------
 
 
+from pyface.ui_traits import (
+    Alignment,
+    Border,
+    HasBorder,
+    HasMargin,
+    Image,
+    Margin,
+    Position,
+    convert_bitmap,
+    convert_image,
+)
+from traits.api import (
+    Any,
+    Delegate,
+    Enum,
+    Expression,
+    Float,
+    HasStrictTraits,
+    List,
+    Range,
+    Str,
+    Trait,
+    TraitError,
+    TraitPrefixList,
+    TraitType,
+)
 
-from pyface.ui_traits import (Alignment, Border, HasBorder, HasMargin, Image,
-                             Margin, Position, convert_bitmap, convert_image)
-from traits.api import (Any, Delegate, Enum, Expression, Float, HasStrictTraits,
-    List, Range, Str, Trait, TraitError, TraitPrefixList, TraitType)
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #  Trait definitions:
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 
 # Orientation trait:
-Orientation = Trait('vertical',
-                    TraitPrefixList('vertical', 'horizontal'))
+Orientation = Trait("vertical", TraitPrefixList("vertical", "horizontal"))
 
 # Styles for user interface elements:
 EditorStyle = style_trait = Trait(
-    'simple',
-    TraitPrefixList(
-        'simple',
-        'custom',
-        'text',
-        'readonly'),
-    cols=4)
+    "simple", TraitPrefixList("simple", "custom", "text", "readonly"), cols=4
+)
 
 # Group layout trait:
-Layout = Trait('normal',
-               TraitPrefixList('normal', 'split', 'tabbed', 'flow', 'fold'))
+Layout = Trait(
+    "normal", TraitPrefixList("normal", "split", "tabbed", "flow", "fold")
+)
 
 # Trait for the default object being edited:
-AnObject = Expression('object')
+AnObject = Expression("object")
 
 # The default dock style to use:
-DockStyle = dock_style_trait = Enum('fixed', 'horizontal', 'vertical', 'tab',
-                                    desc="the default docking style to use")
+DockStyle = dock_style_trait = Enum(
+    "fixed",
+    "horizontal",
+    "vertical",
+    "tab",
+    desc="the default docking style to use",
+)
 
 # The category of elements dragged out of the view:
-ExportType = Str(desc='the category of elements dragged out of the view')
+ExportType = Str(desc="the category of elements dragged out of the view")
 
 # Delegate a trait value to the object's **container** trait:
-ContainerDelegate = container_delegate = Delegate('container',
-                                                  listenable=False)
+ContainerDelegate = container_delegate = Delegate(
+    "container", listenable=False
+)
 
 # An identifier for the external help context:
 HelpId = help_id_trait = Str(desc="the external help context identifier")
 
 # A button to add to a view:
-AButton = Any
-#AButton = Trait( '', Str, Instance( 'traitsui.menu.Action' ) )
+AButton = Any()
+# AButton = Trait( '', Str, Instance( 'traitsui.menu.Action' ) )
 
 # The set of buttons to add to the view:
-Buttons = List(AButton,
-               desc='the action buttons to add to the bottom of the view')
+Buttons = List(
+    AButton, desc="the action buttons to add to the bottom of the view"
+)
 
 # View trait specified by name or instance:
-AView = Any
-#AView = Trait( '', Str, Instance( 'traitsui.view.View' ) )
+AView = Any()
+# AView = Trait( '', Str, Instance( 'traitsui.view.View' ) )
 
 # FIXME: on AButton and AView: TraitCompound handlers with deferred-import
 # Instance traits are just broken. The Instance trait tries to update the
@@ -87,21 +108,21 @@ AView = Any
 # fast_validate table is not updated although the TraitCompound's slow_validates
 # table is modified.
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #  'StatusItem' class:
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 
 
 class StatusItem(HasStrictTraits):
 
-    # The name of the trait the status information will be synched with:
-    name = Str('status')
+    #: The name of the trait the status information will be synched with:
+    name = Str("status")
 
-    # The width of the status field. The possible values are:
-    #
-    #   - abs( width )  > 1.0: Width of the field in pixels = abs( width )
-    #   - abs( width ) <= 1.0: Relative width of the field when compared to
-    #                          the other relative width fields.
+    #: The width of the status field. The possible values are:
+    #:
+    #:   - abs( width )  > 1.0: Width of the field in pixels = abs( width )
+    #:   - abs( width ) <= 1.0: Relative width of the field when compared to
+    #:                          the other relative width fields.
     width = Float(0.5)
 
     def __init__(self, value=None, **traits):
@@ -112,9 +133,10 @@ class StatusItem(HasStrictTraits):
         if value is not None:
             self.name = value
 
-#-------------------------------------------------------------------------
+
+# -------------------------------------------------------------------------
 #  'ViewStatus' trait:
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 
 
 class ViewStatus(TraitType):
@@ -122,12 +144,14 @@ class ViewStatus(TraitType):
         list of StatusItem instances.
     """
 
-    # Define the default value for the trait:
+    #: Define the default value for the trait:
     default_value = None
 
-    # A description of the type of value this trait accepts:
-    info_text = ('None, a string, a single StatusItem instance, or a list or '
-                 'tuple of strings and/or StatusItem instances')
+    #: A description of the type of value this trait accepts:
+    info_text = (
+        "None, a string, a single StatusItem instance, or a list or "
+        "tuple of strings and/or StatusItem instances"
+    )
 
     def validate(self, object, name, value):
         """ Validates that a specified value is valid for this trait.
@@ -156,9 +180,9 @@ class ViewStatus(TraitType):
         self.error(object, name, value)
 
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #  'ATheme' trait:
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 
 
 def convert_theme(value, level=3):
@@ -167,7 +191,7 @@ def convert_theme(value, level=3):
     if not isinstance(value, str):
         return value
 
-    if (value[:1] == '@') and (value.find(':') >= 2):
+    if (value[:1] == "@") and (value.find(":") >= 2):
         try:
             from .image.image import ImageLibrary
 
@@ -179,6 +203,7 @@ def convert_theme(value, level=3):
             return info.theme
 
     from .theme import Theme
+
     return Theme(image=convert_image(value, level + 1))
 
 
@@ -187,11 +212,11 @@ class ATheme(TraitType):
         can be converted to one.
     """
 
-    # Define the default value for the trait:
+    #: Define the default value for the trait:
     default_value = None
 
-    # A description of the type of value this trait accepts:
-    info_text = 'a Theme or string that can be used to define one'
+    #: A description of the type of value this trait accepts:
+    info_text = "a Theme or string that can be used to define one"
 
     def __init__(self, value=None, **metadata):
         """ Creates an ATheme trait.
@@ -218,15 +243,16 @@ class ATheme(TraitType):
 
         self.error(object, name, value)
 
-#-------------------------------------------------------------------------------
+
+# -------------------------------------------------------------------------------
 #  Other trait definitions:
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 
 # The spacing between two items:
 Spacing = Range(-32, 32, 3)
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #  Other definitions:
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 
 SequenceTypes = (tuple, list)
