@@ -1,10 +1,10 @@
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #
 #  Copyright (c) 2005, Enthought, Inc.
 #  All rights reserved.
 #
 #  This software is provided without warranty under the terms of the BSD
-#  license included in enthought/LICENSE.txt and may be redistributed only
+#  license included in LICENSE.txt and may be redistributed only
 #  under the conditions described in the aforementioned license.  The license
 #  is also available online at http://www.enthought.com/licenses/BSD.txt
 #
@@ -13,56 +13,64 @@
 #  Author: David C. Morrill
 #  Date:   10/21/2004
 #
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 
 """ Defines the various font editors and the font editor factory, for the
     wxPython user interface toolkit..
 """
 
-#-------------------------------------------------------------------------
-#  Imports:
-#-------------------------------------------------------------------------
 
 import wx
 
 from traits.api import Bool
 
-from traitsui.editors.font_editor \
-    import ToolkitEditorFactory as BaseToolkitEditorFactory
+from traitsui.editors.font_editor import (
+    ToolkitEditorFactory as BaseToolkitEditorFactory,
+)
 
-from .editor_factory \
-    import SimpleEditor as BaseSimpleEditor, \
-    TextEditor as BaseTextEditor, \
-    ReadonlyEditor as BaseReadonlyEditor
+from .editor_factory import (
+    SimpleEditor as BaseSimpleEditor,
+    TextEditor as BaseTextEditor,
+    ReadonlyEditor as BaseReadonlyEditor,
+)
 
-from .editor \
-    import Editor
+from .editor import Editor
 
-from .helper \
-    import TraitsUIPanel, disconnect
+from .helper import TraitsUIPanel, disconnect
 
-#-------------------------------------------------------------------------
-#  Constants:
-#-------------------------------------------------------------------------
 
 # Standard font point sizes
 PointSizes = [
-    '8', '9', '10', '11', '12', '14', '16', '18',
-    '20', '22', '24', '26', '28', '36', '48', '72'
+    "8",
+    "9",
+    "10",
+    "11",
+    "12",
+    "14",
+    "16",
+    "18",
+    "20",
+    "22",
+    "24",
+    "26",
+    "28",
+    "36",
+    "48",
+    "72",
 ]
 
 # All available font styles
-Styles = ['Normal', 'Slant', 'Italic']
+Styles = ["Normal", "Slant", "Italic"]
 
 # All available font weights
-Weights = ['Normal', 'Light', 'Bold']
+Weights = ["Normal", "Light", "Bold"]
 
 # All available font facenames
 facenames = None
 
-#---------------------------------------------------------------------------
+# ---------------------------------------------------------------------------
 #  The wxPython ToolkitEditorFactory class.
-#---------------------------------------------------------------------------
+# ---------------------------------------------------------------------------
 ## We need to add wx-specific methods to the editor factory, and so we create
 ## a subclass of the BaseToolkitEditorFactory.
 
@@ -74,45 +82,42 @@ class ToolkitEditorFactory(BaseToolkitEditorFactory):
     show_style = Bool(False)
     show_weight = Bool(False)
 
-    #-------------------------------------------------------------------------
-    #  Returns a wxFont object corresponding to a specified object's font trait:
-    #-------------------------------------------------------------------------
-
     def to_wx_font(self, editor):
         """ Returns a wxFont object corresponding to a specified object's font
         trait.
         """
         font = editor.value
-        return wx.Font(font.GetPointSize(), font.GetFamily(), font.GetStyle(),
-                       font.GetWeight(), font.GetUnderlined(),
-                       font.GetFaceName())
-
-    #-------------------------------------------------------------------------
-    #  Gets the application equivalent of a wxPython Font value:
-    #-------------------------------------------------------------------------
+        return wx.Font(
+            font.GetPointSize(),
+            font.GetFamily(),
+            font.GetStyle(),
+            font.GetWeight(),
+            font.GetUnderlined(),
+            font.GetFaceName(),
+        )
 
     def from_wx_font(self, font):
         """ Gets the application equivalent of a wxPython Font value.
         """
         return font
 
-    #-------------------------------------------------------------------------
-    #  Returns the text representation of the specified object trait value:
-    #-------------------------------------------------------------------------
-
     def str_font(self, font):
         """ Returns the text representation of the specified object trait value.
         """
-        weight = {wx.FONTWEIGHT_LIGHT: ' Light',
-                  wx.FONTWEIGHT_BOLD: ' Bold'}.get(font.GetWeight(), '')
-        style = {wx.FONTSTYLE_SLANT: ' Slant',
-                 wx.FONTSTYLE_ITALIC: ' Italic'}.get(font.GetStyle(), '')
-        return '%s point %s%s%s' % (
-            font.GetPointSize(), font.GetFaceName(), style, weight)
-
-    #-------------------------------------------------------------------------
-    #  Returns a list of all available font facenames:
-    #-------------------------------------------------------------------------
+        weight = {
+            wx.FONTWEIGHT_LIGHT: " Light",
+            wx.FONTWEIGHT_BOLD: " Bold",
+        }.get(font.GetWeight(), "")
+        style = {
+            wx.FONTSTYLE_SLANT: " Slant",
+            wx.FONTSTYLE_ITALIC: " Italic",
+        }.get(font.GetStyle(), "")
+        return "%s point %s%s%s" % (
+            font.GetPointSize(),
+            font.GetFaceName(),
+            style,
+            weight,
+        )
 
     def all_facenames(self):
         """ Returns a list of all available font facenames.
@@ -123,9 +128,10 @@ class ToolkitEditorFactory(BaseToolkitEditorFactory):
             facenames = sorted(FontEnumerator().facenames())
         return facenames
 
-#-------------------------------------------------------------------------
+
+# -------------------------------------------------------------------------
 #  'SimpleFontEditor' class:
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 
 
 class SimpleFontEditor(BaseSimpleEditor):
@@ -134,10 +140,6 @@ class SimpleFontEditor(BaseSimpleEditor):
         Clicking the field displays a font selection dialog box.
     """
 
-    #-------------------------------------------------------------------------
-    #  Invokes the pop-up editor for an object trait:
-    #-------------------------------------------------------------------------
-
     def popup_editor(self, event):
         """ Invokes the pop-up editor for an object trait.
         """
@@ -146,15 +148,12 @@ class SimpleFontEditor(BaseSimpleEditor):
         dialog = wx.FontDialog(self.control, font_data)
         if dialog.ShowModal() == wx.ID_OK:
             self.value = self.factory.from_wx_font(
-                dialog.GetFontData().GetChosenFont())
+                dialog.GetFontData().GetChosenFont()
+            )
             self.update_editor()
 
         dialog.Destroy()
 
-    #-------------------------------------------------------------------------
-    #  Updates the editor when the object trait changes external to the editor:
-    #-------------------------------------------------------------------------
-
     def update_editor(self):
         """ Updates the editor when the object trait changes externally to the
             editor.
@@ -162,19 +161,11 @@ class SimpleFontEditor(BaseSimpleEditor):
         super(SimpleFontEditor, self).update_editor()
         set_font(self)
 
-    #-------------------------------------------------------------------------
-    #  Returns the text representation of a specified font value:
-    #-------------------------------------------------------------------------
-
     def string_value(self, font):
         """ Returns the text representation of a specified font value.
         """
         return self.factory.str_font(font)
 
-#-------------------------------------------------------------------------
-#  'CustomFontEditor' class:
-#-------------------------------------------------------------------------
-
 
 class CustomFontEditor(Editor):
     """ Custom style of font editor, which displays the following:
@@ -184,11 +175,6 @@ class CustomFontEditor(Editor):
         * A combo box containing the available type styles
     """
 
-    #-------------------------------------------------------------------------
-    #  Finishes initializing the editor by creating the underlying toolkit
-    #  widget:
-    #-------------------------------------------------------------------------
-
     def init(self, parent):
         """ Finishes initializing the editor by creating the underlying toolkit
             widget.
@@ -200,31 +186,32 @@ class CustomFontEditor(Editor):
         # Add all of the font choice controls:
         sizer2 = wx.BoxSizer(wx.HORIZONTAL)
         facenames = self.factory.all_facenames()
-        control = self._facename = wx.Choice(panel, -1, wx.Point(0, 0),
-                                             wx.Size(-1, -1), facenames)
+        control = self._facename = wx.Choice(
+            panel, -1, wx.Point(0, 0), wx.Size(-1, -1), facenames
+        )
 
         sizer2.Add(control, 4, wx.EXPAND)
-        wx.EVT_CHOICE(panel, control.GetId(), self.update_object_parts)
+        panel.Bind(wx.EVT_CHOICE, self.update_object_parts, id=control.GetId())
 
-        control = self._point_size = wx.Choice(panel, -1, wx.Point(0, 0),
-                                               wx.Size(-1, -1), PointSizes)
+        control = self._point_size = wx.Choice(
+            panel, -1, wx.Point(0, 0), wx.Size(-1, -1), PointSizes
+        )
         sizer2.Add(control, 1, wx.EXPAND | wx.LEFT, 3)
-        wx.EVT_CHOICE(panel, control.GetId(), self.update_object_parts)
+        panel.Bind(wx.EVT_CHOICE, self.update_object_parts, id=control.GetId())
 
         if self.factory.show_style:
-            self._style = wx.Choice(panel, -1, wx.Point(0, 0),
-                                    wx.Size(-1, -1), Styles)
+            self._style = wx.Choice(
+                panel, -1, wx.Point(0, 0), wx.Size(-1, -1), Styles
+            )
             sizer2.Add(self._style, 1, wx.EXPAND | wx.LEFT, 3)
-            wx.EVT_CHOICE(panel, self._style.GetId(), self.update_object_parts)
+            panel.Bind(wx.EVT_CHOICE, self.update_object_parts, id=self._style.GetId())
 
         if self.factory.show_weight:
-            self._weight = wx.Choice(panel, -1, wx.Point(0, 0),
-                                     wx.Size(-1, -1), Weights)
+            self._weight = wx.Choice(
+                panel, -1, wx.Point(0, 0), wx.Size(-1, -1), Weights
+            )
             sizer2.Add(self._weight, 1, wx.EXPAND | wx.LEFT, 3)
-            wx.EVT_CHOICE(
-                panel,
-                self._weight.GetId(),
-                self.update_object_parts)
+            panel.Bind(wx.EVT_CHOICE, self.update_object_parts, id=self._weight.GetId())
 
         sizer.Add(sizer2, 0, wx.EXPAND)
 
@@ -233,10 +220,6 @@ class CustomFontEditor(Editor):
 
         self.set_tooltip()
 
-    #-------------------------------------------------------------------------
-    #  Disposes of the contents of an editor:
-    #-------------------------------------------------------------------------
-
     def dispose(self):
         """ Disposes of the contents of an editor.
         """
@@ -249,10 +232,6 @@ class CustomFontEditor(Editor):
 
         super(CustomFontEditor, self).dispose()
 
-    #-------------------------------------------------------------------------
-    #  Handles the user modifying one of the font components:
-    #-------------------------------------------------------------------------
-
     def update_object_parts(self, event):
         """ Handles the user modifying one of the font components.
         """
@@ -267,14 +246,11 @@ class CustomFontEditor(Editor):
         if self.factory.show_weight:
             weight += self._weight.GetCurrentSelection()
 
-        font = wx.Font(point_size, wx.FONTFAMILY_DEFAULT, style, weight,
-                       faceName=facename)
+        font = wx.Font(
+            point_size, wx.FONTFAMILY_DEFAULT, style, weight, faceName=facename
+        )
         self.value = self.factory.from_wx_font(font)
 
-    #-------------------------------------------------------------------------
-    #  Updates the editor when the object trait changes external to the editor:
-    #-------------------------------------------------------------------------
-
     def update_editor(self):
         """ Updates the editor when the object trait changes externally to the
             editor.
@@ -291,19 +267,16 @@ class CustomFontEditor(Editor):
         except:
             self._point_size.SetSelection(0)
 
-    #-------------------------------------------------------------------------
-    #  Returns the text representation of a specified font value:
-    #-------------------------------------------------------------------------
-
     def string_value(self, font):
         """ Returns the text representation of a specified font value.
         """
         return self.factory.str_font(font)
 
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #  'TextFontEditor' class:
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
+
 
 class TextFontEditor(BaseTextEditor):
     """ Text style of font editor, which displays an editable text field
@@ -311,19 +284,11 @@ class TextFontEditor(BaseTextEditor):
         possible).
     """
 
-    #-------------------------------------------------------------------------
-    #  Handles the user changing the contents of the edit control:
-    #-------------------------------------------------------------------------
-
     def update_object(self, event):
         """ Handles the user changing the contents of the edit control.
         """
         self.value = self.control.GetValue()
 
-    #-------------------------------------------------------------------------
-    #  Updates the editor when the object trait changes external to the editor:
-    #-------------------------------------------------------------------------
-
     def update_editor(self):
         """ Updates the editor when the object trait changes external to the
             editor.
@@ -331,19 +296,11 @@ class TextFontEditor(BaseTextEditor):
         super(TextFontEditor, self).update_editor()
         set_font(self)
 
-    #-------------------------------------------------------------------------
-    #  Returns the text representation of a specified font value:
-    #-------------------------------------------------------------------------
-
     def string_value(self, font):
         """ Returns the text representation of a specified font value.
         """
         return self.factory.str_font(font)
 
-#-------------------------------------------------------------------------
-#  'ReadonlyFontEditor' class:
-#-------------------------------------------------------------------------
-
 
 class ReadonlyFontEditor(BaseReadonlyEditor):
     """ Read-only style of font editor, which displays a read-only text field
@@ -351,10 +308,6 @@ class ReadonlyFontEditor(BaseReadonlyEditor):
         possible).
     """
 
-    #-------------------------------------------------------------------------
-    #  Updates the editor when the object trait changes external to the editor:
-    #-------------------------------------------------------------------------
-
     def update_editor(self):
         """ Updates the editor when the object trait changes external to the
             editor.
@@ -362,18 +315,15 @@ class ReadonlyFontEditor(BaseReadonlyEditor):
         super(ReadonlyFontEditor, self).update_editor()
         set_font(self)
 
-    #-------------------------------------------------------------------------
-    #  Returns the text representation of a specified font value:
-    #-------------------------------------------------------------------------
-
     def string_value(self, font):
         """ Returns the text representation of a specified font value.
         """
         return self.factory.str_font(font)
 
-#-------------------------------------------------------------------------
+
+# -------------------------------------------------------------------------
 #  Set the editor control's font to match a specified font:
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 
 
 def set_font(editor):
@@ -383,17 +333,10 @@ def set_font(editor):
     font.SetPointSize(min(10, font.GetPointSize()))
     editor.control.SetFont(font)
 
-#-------------------------------------------------------------------------
-#  'FontEnumerator' class:
-#-------------------------------------------------------------------------
-
 
 class FontEnumerator(wx.FontEnumerator):
     """ An enumeration of fonts.
     """
-    #-------------------------------------------------------------------------
-    #  Returns a list of all available font facenames:
-    #-------------------------------------------------------------------------
 
     def facenames(self):
         """ Returns a list of all available font facenames.
@@ -402,21 +345,16 @@ class FontEnumerator(wx.FontEnumerator):
         self.EnumerateFacenames()
         return self._facenames
 
-    #-------------------------------------------------------------------------
-    #  Adds a facename to the list of facenames:
-    #-------------------------------------------------------------------------
-
     def OnFacename(self, facename):
         """ Adds a facename to the list of facenames.
         """
         self._facenames.append(facename)
         return True
 
+
 # Define the names SimpleEditor, CustomEditor, TextEditor and ReadonlyEditor
 # which are looked up by the editor factory for the font editor.
 SimpleEditor = SimpleFontEditor
 CustomEditor = CustomFontEditor
 TextEditor = TextFontEditor
 ReadonlyEditor = ReadonlyFontEditor
-
-### EOF #######################################################################
