@@ -1,10 +1,10 @@
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 #  Copyright (c) 2007-13, Enthought, Inc.
 #  All rights reserved.
 #
 #  This software is provided without warranty under the terms of the BSD
-#  license included in enthought/LICENSE.txt and may be redistributed only
+#  license included in LICENSE.txt and may be redistributed only
 #  under the conditions described in the aforementioned license.  The license
 #  is also available online at http://www.enthought.com/licenses/BSD.txt
 #
@@ -13,50 +13,47 @@
 #  Author: David C. Morrill
 #  Date:   05/08/2007
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 
 """ Traits UI editor for editing lists of strings.
 """
 
-#-------------------------------------------------------------------------
-#  Imports:
-#-------------------------------------------------------------------------
 
-from __future__ import absolute_import
 import wx
 
-from traits.api \
-    import Str, Int, List, Bool, Instance, Any, Event, TraitListEvent, \
-    Property
+from traits.api import (
+    Str,
+    Int,
+    List,
+    Bool,
+    Instance,
+    Any,
+    Event,
+    TraitListEvent,
+    Property,
+)
 
 # FIXME: ListStrEditor is a proxy class defined here just for backward
 # compatibility. The class has been moved to the
 # traitsui.editors.list_editor file.
-from traitsui.editors.list_str_editor \
-    import ListStrEditor
+from traitsui.editors.list_str_editor import ListStrEditor
 
-from traitsui.list_str_adapter \
-    import ListStrAdapter
+from traitsui.list_str_adapter import ListStrAdapter
 
-from traitsui.wx.editor \
-    import Editor
+from traitsui.wx.editor import Editor
 
-from pyface.image_resource \
-    import ImageResource
+from pyface.image_resource import ImageResource
 
-from .helper \
-    import disconnect, disconnect_no_id
-from six.moves import range
+from .helper import disconnect, disconnect_no_id
 
 try:
-    from pyface.wx.drag_and_drop \
-        import PythonDropSource, PythonDropTarget
+    from pyface.wx.drag_and_drop import PythonDropSource, PythonDropTarget
 except:
     PythonDropSource = PythonDropTarget = None
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #  'wxListCtrl' class:
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 
 
 class wxListCtrl(wx.ListCtrl):
@@ -75,8 +72,7 @@ class wxListCtrl(wx.ListCtrl):
         adapter = editor.adapter
 
         if editor._is_auto_add(index):
-            bg_color = adapter.get_default_bg_color(editor.object,
-                                                    editor.name)
+            bg_color = adapter.get_default_bg_color(editor.object, editor.name)
             color = adapter.get_default_text_color(editor.object, editor.name)
         else:
             bg_color = adapter.get_bg_color(editor.object, editor.name, index)
@@ -95,11 +91,11 @@ class wxListCtrl(wx.ListCtrl):
         """
         editor = self._editor
         if editor._is_auto_add(index):
-            image = editor.adapter.get_default_image(editor.object,
-                                                     editor.name)
+            image = editor.adapter.get_default_image(
+                editor.object, editor.name
+            )
         else:
-            image = editor.adapter.get_image(editor.object, editor.name,
-                                             index)
+            image = editor.adapter.get_image(editor.object, editor.name, index)
 
         image = editor._get_image(image)
         if image is not None:
@@ -117,66 +113,57 @@ class wxListCtrl(wx.ListCtrl):
 
         return editor.adapter.get_text(editor.object, editor.name, index)
 
-#-------------------------------------------------------------------------
-#  '_ListStrEditor' class:
-#-------------------------------------------------------------------------
-
 
 class _ListStrEditor(Editor):
     """ Traits UI editor for editing lists of strings.
     """
 
-    #-- Trait Definitions ----------------------------------------------------
+    # -- Trait Definitions ----------------------------------------------------
 
-    # The title of the editor:
-    title = Str
+    #: The title of the editor:
+    title = Str()
 
-    # The current set of selected items (which one is used depends upon the
-    # initial state of the editor factory 'multi_select' trait):
-    selected = Any
-    multi_selected = List
+    #: The current set of selected items (which one is used depends upon the
+    #: initial state of the editor factory 'multi_select' trait):
+    selected = Any()
+    multi_selected = List()
 
-    # The current set of selected item indices (which one is used depends upon
-    # the initial state of the editor factory 'multi_select' trait):
-    selected_index = Int
+    #: The current set of selected item indices (which one is used depends upon
+    #: the initial state of the editor factory 'multi_select' trait):
+    selected_index = Int()
     multi_selected_indices = List(Int)
 
-    # The most recently actived item and its index:
-    activated = Any
-    activated_index = Int
+    #: The most recently actived item and its index:
+    activated = Any()
+    activated_index = Int()
 
-    # The most recently right_clicked item and its index:
-    right_clicked = Event
-    right_clicked_index = Event
+    #: The most recently right_clicked item and its index:
+    right_clicked = Event()
+    right_clicked_index = Event()
 
-    # Is the list editor scrollable? This value overrides the default.
+    #: Is the list editor scrollable? This value overrides the default.
     scrollable = True
 
-    # Index of item to select after rebuilding editor list:
-    index = Any
+    #: Index of item to select after rebuilding editor list:
+    index = Any()
 
-    # Should the selected item be edited after rebuilding the editor list:
+    #: Should the selected item be edited after rebuilding the editor list:
     edit = Bool(False)
 
-    # The adapter from list items to editor values:
+    #: The adapter from list items to editor values:
     adapter = Instance(ListStrAdapter)
 
-    # Dictionaly mapping image names to wx.ImageList indices:
+    #: Dictionaly mapping image names to wx.ImageList indices:
     images = Any({})
 
-    # Dictionary mapping ImageResource objects to wx.ImageList indices:
+    #: Dictionary mapping ImageResource objects to wx.ImageList indices:
     image_resources = Any({})
 
-    # The current number of item currently in the list:
-    item_count = Property
+    #: The current number of item currently in the list:
+    item_count = Property()
 
-    # The current search string:
-    search = Str
-
-    #-------------------------------------------------------------------------
-    #  Finishes initializing the editor by creating the underlying toolkit
-    #  widget:
-    #-------------------------------------------------------------------------
+    #: The current search string:
+    search = Str()
 
     def init(self, parent):
         """ Finishes initializing the editor by creating the underlying toolkit
@@ -186,7 +173,7 @@ class _ListStrEditor(Editor):
 
         # Set up the adapter to use:
         self.adapter = factory.adapter
-        self.sync_value(factory.adapter_name, 'adapter', 'from')
+        self.sync_value(factory.adapter_name, "adapter", "from")
 
         # Determine the style to use for the list control:
         style = wx.LC_REPORT | wx.LC_VIRTUAL
@@ -200,7 +187,7 @@ class _ListStrEditor(Editor):
         if not factory.multi_select:
             style |= wx.LC_SINGLE_SEL
 
-        if (factory.title == '') and (factory.title_name == ''):
+        if (factory.title == "") and (factory.title_name == ""):
             style |= wx.LC_NO_HEADER
 
         # Create the list control and link it back to us:
@@ -208,25 +195,24 @@ class _ListStrEditor(Editor):
         control._editor = self
 
         # Create the list control column:
-        control.InsertColumn(0, '')
+        control.InsertColumn(0, "")
 
         # Set up the list control's event handlers:
-        id = control.GetId()
-        wx.EVT_LIST_BEGIN_DRAG(parent, id, self._begin_drag)
-        wx.EVT_LIST_BEGIN_LABEL_EDIT(parent, id, self._begin_label_edit)
-        wx.EVT_LIST_END_LABEL_EDIT(parent, id, self._end_label_edit)
-        wx.EVT_LIST_ITEM_SELECTED(parent, id, self._item_selected)
-        wx.EVT_LIST_ITEM_DESELECTED(parent, id, self._item_selected)
-        wx.EVT_LIST_ITEM_RIGHT_CLICK(parent, id, self._right_clicked)
-        wx.EVT_LIST_ITEM_ACTIVATED(parent, id, self._item_activated)
-        wx.EVT_SIZE(control, self._size_modified)
+        control.Bind(wx.EVT_LIST_BEGIN_DRAG, self._begin_drag)
+        control.Bind(wx.EVT_LIST_BEGIN_LABEL_EDIT, self._begin_label_edit)
+        control.Bind(wx.EVT_LIST_END_LABEL_EDIT, self._end_label_edit)
+        control.Bind(wx.EVT_LIST_ITEM_SELECTED, self._item_selected)
+        control.Bind(wx.EVT_LIST_ITEM_DESELECTED, self._item_selected)
+        control.Bind(wx.EVT_LIST_ITEM_RIGHT_CLICK, self._right_clicked)
+        control.Bind(wx.EVT_LIST_ITEM_ACTIVATED, self._item_activated)
+        control.Bind(wx.EVT_SIZE, self._size_modified)
 
         # Handle key events:
-        wx.EVT_CHAR(control, self._key_pressed)
+        control.Bind(wx.EVT_CHAR, self._key_pressed)
 
         # Handle mouse events:
-        if 'edit' in factory.operations:
-            wx.EVT_LEFT_DOWN(control, self._left_down)
+        if "edit" in factory.operations:
+            control.Bind(wx.EVT_LEFT_DOWN, self._left_down)
 
         # Set up the drag and drop target:
         if PythonDropTarget is not None:
@@ -234,40 +220,44 @@ class _ListStrEditor(Editor):
 
         # Initialize the editor title:
         self.title = factory.title
-        self.sync_value(factory.title_name, 'title', 'from')
+        self.sync_value(factory.title_name, "title", "from")
 
         # Set up the selection listener (if necessary):
         if factory.multi_select:
-            self.sync_value(factory.selected, 'multi_selected', 'both',
-                            is_list=True)
-            self.sync_value(factory.selected_index, 'multi_selected_indices',
-                            'both', is_list=True)
+            self.sync_value(
+                factory.selected, "multi_selected", "both", is_list=True
+            )
+            self.sync_value(
+                factory.selected_index,
+                "multi_selected_indices",
+                "both",
+                is_list=True,
+            )
         else:
-            self.sync_value(factory.selected, 'selected', 'both')
-            self.sync_value(factory.selected_index, 'selected_index', 'both')
+            self.sync_value(factory.selected, "selected", "both")
+            self.sync_value(factory.selected_index, "selected_index", "both")
 
         # Synchronize other interesting traits as necessary:
-        self.sync_value(factory.activated, 'activated', 'to')
-        self.sync_value(factory.activated_index, 'activated_index', 'to')
+        self.sync_value(factory.activated, "activated", "to")
+        self.sync_value(factory.activated_index, "activated_index", "to")
 
-        self.sync_value(factory.right_clicked, 'right_clicked', 'to')
-        self.sync_value(factory.right_clicked_index, 'right_clicked_index',
-                        'to')
+        self.sync_value(factory.right_clicked, "right_clicked", "to")
+        self.sync_value(
+            factory.right_clicked_index, "right_clicked_index", "to"
+        )
 
         # Make sure we listen for 'items' changes as well as complete list
         # replacements:
         self.context_object.on_trait_change(
-            self.update_editor,
-            self.extended_name + '_items',
-            dispatch='ui')
+            self.update_editor, self.extended_name + "_items", dispatch="ui"
+        )
 
         # Create the mapping from user supplied images to wx.ImageList indices:
         for image_resource in factory.images:
             self._add_image(image_resource)
 
         # Refresh the editor whenever the adapter changes:
-        self.on_trait_change(self._refresh, 'adapter.+update',
-                             dispatch='ui')
+        self.on_trait_change(self._refresh, "adapter.+update", dispatch="ui")
 
         # Set the list control's tooltip:
         self.set_tooltip()
@@ -275,19 +265,24 @@ class _ListStrEditor(Editor):
     def dispose(self):
         """ Disposes of the contents of an editor.
         """
-        disconnect(self.control, wx.EVT_LIST_BEGIN_DRAG,
-                   wx.EVT_LIST_BEGIN_LABEL_EDIT, wx.EVT_LIST_END_LABEL_EDIT,
-                   wx.EVT_LIST_ITEM_SELECTED, wx.EVT_LIST_ITEM_DESELECTED,
-                   wx.EVT_LIST_ITEM_RIGHT_CLICK, wx.EVT_LIST_ITEM_ACTIVATED)
-
-        disconnect_no_id(self.control,
-                         wx.EVT_SIZE, wx.EVT_CHAR, wx.EVT_LEFT_DOWN)
+        disconnect_no_id(
+            self.control,
+            wx.EVT_SIZE,
+            wx.EVT_CHAR,
+            wx.EVT_LEFT_DOWN,
+            wx.EVT_LIST_BEGIN_DRAG,
+            wx.EVT_LIST_BEGIN_LABEL_EDIT,
+            wx.EVT_LIST_END_LABEL_EDIT,
+            wx.EVT_LIST_ITEM_SELECTED,
+            wx.EVT_LIST_ITEM_DESELECTED,
+            wx.EVT_LIST_ITEM_RIGHT_CLICK,
+            wx.EVT_LIST_ITEM_ACTIVATED,
+        )
 
         self.context_object.on_trait_change(
-            self.update_editor,
-            self.extended_name + '_items',
-            remove=True)
-        self.on_trait_change(self._refresh, 'adapter.+update', remove=True)
+            self.update_editor, self.extended_name + "_items", remove=True
+        )
+        self.on_trait_change(self._refresh, "adapter.+update", remove=True)
 
         super(_ListStrEditor, self).dispose()
 
@@ -306,7 +301,7 @@ class _ListStrEditor(Editor):
         control.SetItemCount(n)
         if control.GetItemCount() > 0:
             control.RefreshItems(0, control.GetItemCount() - 1)
-        control.SetColumnWidth(0, control.GetClientSizeTuple()[0])
+        control.SetColumnWidth(0, control.GetClientSize()[0])
 
         edit, self.edit = self.edit, False
         index, self.index = self.index, None
@@ -324,36 +319,42 @@ class _ListStrEditor(Editor):
             if self.factory.multi_select:
                 for index in self.multi_selected_indices:
                     if 0 <= index < n:
-                        control.SetItemState(index, wx.LIST_STATE_SELECTED,
-                                             wx.LIST_STATE_SELECTED)
+                        control.SetItemState(
+                            index,
+                            wx.LIST_STATE_SELECTED,
+                            wx.LIST_STATE_SELECTED,
+                        )
             else:
                 if 0 <= self.selected_index < n:
                     control.SetItemState(
                         self.selected_index,
                         wx.LIST_STATE_SELECTED,
-                        wx.LIST_STATE_SELECTED)
+                        wx.LIST_STATE_SELECTED,
+                    )
             return
 
         if 0 <= (index - top) < pn:
-            control.EnsureVisible(max(0, top + pn - 2))
+            control.EnsureVisible(min(top + pn - 2, control.GetItemCount() - 1))
         elif index < top:
-            control.EnsureVisible(min(n, index + pn - 1))
+            control.EnsureVisible(min(index + pn - 1, control.GetItemCount() - 1))
         else:
             control.EnsureVisible(index)
 
-        control.SetItemState(index,
-                             wx.LIST_STATE_SELECTED | wx.LIST_STATE_FOCUSED,
-                             wx.LIST_STATE_SELECTED | wx.LIST_STATE_FOCUSED)
+        control.SetItemState(
+            index,
+            wx.LIST_STATE_SELECTED | wx.LIST_STATE_FOCUSED,
+            wx.LIST_STATE_SELECTED | wx.LIST_STATE_FOCUSED,
+        )
 
         if edit:
             control.EditLabel(index)
 
-    #-- Property Implementations ---------------------------------------------
+    # -- Property Implementations ---------------------------------------------
 
     def _get_item_count(self):
-        return (self.control.GetItemCount() - self.factory.auto_add)
+        return self.control.GetItemCount() - self.factory.auto_add
 
-    #-- Trait Event Handlers -------------------------------------------------
+    # -- Trait Event Handlers -------------------------------------------------
 
     def _title_changed(self, title):
         """ Handles the editor title being changed.
@@ -370,7 +371,8 @@ class _ListStrEditor(Editor):
                 self.control.SetItemState(
                     self.value.index(selected),
                     wx.LIST_STATE_SELECTED,
-                    wx.LIST_STATE_SELECTED)
+                    wx.LIST_STATE_SELECTED,
+                )
             except Exception:
                 pass
 
@@ -382,7 +384,8 @@ class _ListStrEditor(Editor):
                 self.control.SetItemState(
                     selected_index,
                     wx.LIST_STATE_SELECTED,
-                    wx.LIST_STATE_SELECTED)
+                    wx.LIST_STATE_SELECTED,
+                )
             except Exception:
                 pass
 
@@ -392,8 +395,9 @@ class _ListStrEditor(Editor):
         if not self._no_update:
             values = self.value
             try:
-                self._multi_selected_indices_changed([values.index(item)
-                                                      for item in selected])
+                self._multi_selected_indices_changed(
+                    [values.index(item) for item in selected]
+                )
             except Exception:
                 pass
 
@@ -402,8 +406,13 @@ class _ListStrEditor(Editor):
         """
         values = self.values
         try:
-            self._multi_selected_indices_items_changed(TraitListEvent(0, [values.index(
-                item) for item in event.removed], [values.index(item) for item in event.added]))
+            self._multi_selected_indices_items_changed(
+                TraitListEvent(
+                    0,
+                    [values.index(item) for item in event.removed],
+                    [values.index(item) for item in event.added],
+                )
+            )
         except Exception:
             pass
 
@@ -420,8 +429,11 @@ class _ListStrEditor(Editor):
                     selected.remove(index)
                 else:
                     try:
-                        control.SetItemState(index, wx.LIST_STATE_SELECTED,
-                                             wx.LIST_STATE_SELECTED)
+                        control.SetItemState(
+                            index,
+                            wx.LIST_STATE_SELECTED,
+                            wx.LIST_STATE_SELECTED,
+                        )
                     except Exception:
                         pass
 
@@ -440,10 +452,11 @@ class _ListStrEditor(Editor):
 
         # Select all newly added items:
         for index in event.added:
-            control.SetItemState(index, wx.LIST_STATE_SELECTED,
-                                 wx.LIST_STATE_SELECTED)
+            control.SetItemState(
+                index, wx.LIST_STATE_SELECTED, wx.LIST_STATE_SELECTED
+            )
 
-    #-- List Control Event Handlers ------------------------------------------
+    # -- List Control Event Handlers ------------------------------------------
 
     def _begin_drag(self, event):
         """ Handles the user beginning a drag operation with the left mouse
@@ -478,8 +491,9 @@ class _ListStrEditor(Editor):
                 ds = PythonDropSource(self.control, drag_items)
 
                 # If moves are allowed and the result was a drag move:
-                if ((ds.result == wx.DragMove) and
-                        (self._drag_local or self.factory.drag_move)):
+                if (ds.result == wx.DragMove) and (
+                    self._drag_local or self.factory.drag_move
+                ):
                     # Then delete all of the original items (in reverse order
                     # from highest to lowest, so the indices don't need to be
                     # adjusted):
@@ -496,8 +510,9 @@ class _ListStrEditor(Editor):
         """
         index = event.GetIndex()
 
-        if ((not self._is_auto_add(index)) and (
-                not self.adapter.get_can_edit(self.object, self.name, index))):
+        if (not self._is_auto_add(index)) and (
+            not self.adapter.get_can_edit(self.object, self.name, index)
+        ):
             event.Veto()
 
     def _end_label_edit(self, event):
@@ -515,15 +530,15 @@ class _ListStrEditor(Editor):
             selected_indices = self._get_selected()
             if self.factory.multi_select:
                 self.multi_selected_indices = selected_indices
-                self.multi_selected = [get_item(object, name, index)
-                                       for index in selected_indices]
+                self.multi_selected = [
+                    get_item(object, name, index) for index in selected_indices
+                ]
             elif len(selected_indices) == 0:
                 self.selected_index = -1
                 self.selected = None
             else:
                 self.selected_index = selected_indices[0]
-                self.selected = get_item(object, name,
-                                         selected_indices[0])
+                self.selected = get_item(object, name, selected_indices[0])
         finally:
             self._no_update = False
 
@@ -531,18 +546,20 @@ class _ListStrEditor(Editor):
         """ Handles an item being activated (double-clicked or enter pressed).
         """
         self.activated_index = event.GetIndex()
-        if 'edit' in self.factory.operations:
+        if "edit" in self.factory.operations:
             self._edit_current()
         else:
-            self.activated = self.adapter.get_item(self.object, self.name,
-                                                   self.activated_index)
+            self.activated = self.adapter.get_item(
+                self.object, self.name, self.activated_index
+            )
 
     def _right_clicked(self, event):
         """ Handles an item being right clicked.
         """
         self.right_clicked_index = index = event.GetIndex()
-        self.right_clicked = self.adapter.get_item(self.object, self.name,
-                                                   index)
+        self.right_clicked = self.adapter.get_item(
+            self.object, self.name, index
+        )
 
     def _key_pressed(self, event):
         key = event.GetKeyCode()
@@ -552,10 +569,10 @@ class _ListStrEditor(Editor):
             self.search += chr(key).lower()
             self._search_for_string()
         elif key in (wx.WXK_HOME, wx.WXK_PAGEUP, wx.WXK_PAGEDOWN):
-            self.search = ''
+            self.search = ""
             event.Skip()
         elif key == wx.WXK_END:
-            self.search = ''
+            self.search = ""
             self._append_new()
         elif (key == wx.WXK_UP) and control:
             self._search_for_string(-1)
@@ -571,11 +588,11 @@ class _ListStrEditor(Editor):
             self._move_down_current()
         elif key == wx.WXK_RETURN:
             self._edit_current()
-        elif key == 3:    # Ctrl-C
+        elif key == 3:  # Ctrl-C
             self._copy_current()
-        elif key == 22:   # Ctrl-V
+        elif key == 22:  # Ctrl-V
             self._paste_current()
-        elif key == 24:   # Ctrl-X
+        elif key == 24:  # Ctrl-X
             self._cut_current()
         else:
             event.Skip()
@@ -583,22 +600,23 @@ class _ListStrEditor(Editor):
     def _size_modified(self, event):
         """ Handles the size of the list control being changed.
         """
-        dx, dy = self.control.GetClientSizeTuple()
+        dx, dy = self.control.GetClientSize()
         self.control.SetColumnWidth(0, dx - 1)
         event.Skip()
 
     def _left_down(self, event):
         """ Handles the user pressing the left mouse button.
         """
-        index, flags = self.control.HitTest(wx.Point(event.GetX(),
-                                                     event.GetY()))
+        index, flags = self.control.HitTest(
+            wx.Point(event.GetX(), event.GetY())
+        )
         selected = self._get_selected()
         if (len(selected) == 1) and (index == selected[0]):
             self._edit_current()
         else:
             event.Skip()
 
-    #-- Drag and Drop Event Handlers -----------------------------------------
+    # -- Drag and Drop Event Handlers -----------------------------------------
 
     def wx_dropped_on(self, x, y, data, drag_result):
         """ Handles a Python object being dropped on the list control.
@@ -607,9 +625,11 @@ class _ListStrEditor(Editor):
 
         # If the user dropped it on an empty list, set the target as past the
         # end of the list:
-        if ((index == -1) and
-            ((flags & wx.LIST_HITTEST_NOWHERE) != 0) and
-                (self.control.GetItemCount() == 0)):
+        if (
+            (index == -1)
+            and ((flags & wx.LIST_HITTEST_NOWHERE) != 0)
+            and (self.control.GetItemCount() == 0)
+        ):
             index = 0
 
         # If we have a valid drop target index, proceed:
@@ -646,7 +666,7 @@ class _ListStrEditor(Editor):
         destination = adapter.get_dropped(object, name, index, item)
 
         # Adjust the target index accordingly:
-        if destination == 'after':
+        if destination == "after":
             index += 1
 
         # Insert the dropped item at the requested position:
@@ -679,21 +699,24 @@ class _ListStrEditor(Editor):
 
         # If the user is dragging over an empty list, set the target to the end
         # of the list:
-        if ((index == -1) and
-            ((flags & wx.LIST_HITTEST_NOWHERE) != 0) and
-                (self.control.GetItemCount() == 0)):
+        if (
+            (index == -1)
+            and ((flags & wx.LIST_HITTEST_NOWHERE) != 0)
+            and (self.control.GetItemCount() == 0)
+        ):
             index = 0
 
         # If the drag target index is valid and the adapter says it is OK to
         # drop the data here, then indicate the data can be dropped:
-        if ((index != -1) and
-                self.adapter.get_can_drop(self.object, self.name, index, data)):
+        if (index != -1) and self.adapter.get_can_drop(
+            self.object, self.name, index, data
+        ):
             return drag_result
 
         # Else indicate that we will not accept the data:
         return wx.DragNone
 
-    #-- Private Methods ------------------------------------------------------
+    # -- Private Methods ------------------------------------------------------
 
     def _refresh(self):
         """ Refreshes the contents of the editor's list control.
@@ -707,12 +730,14 @@ class _ListStrEditor(Editor):
 
         image_list = self._image_list
         if image_list is None:
-            self._image_list = image_list = wx.ImageList(bitmap.GetWidth(),
-                                                         bitmap.GetHeight())
+            self._image_list = image_list = wx.ImageList(
+                bitmap.GetWidth(), bitmap.GetHeight()
+            )
             self.control.AssignImageList(image_list, wx.IMAGE_LIST_SMALL)
 
-        self.image_resources[image_resource] = \
-            self.images[image_resource.name] = index = image_list.Add(bitmap)
+        self.image_resources[image_resource] = self.images[
+            image_resource.name
+        ] = index = image_list.Add(bitmap)
 
         return index
 
@@ -735,8 +760,9 @@ class _ListStrEditor(Editor):
         item = -1
         control = self.control
         while True:
-            item = control.GetNextItem(item, wx.LIST_NEXT_ALL,
-                                       wx.LIST_STATE_SELECTED)
+            item = control.GetNextItem(
+                item, wx.LIST_NEXT_ALL, wx.LIST_STATE_SELECTED
+            )
             if item == -1:
                 break
 
@@ -774,7 +800,7 @@ class _ListStrEditor(Editor):
     def _append_new(self):
         """ Append a new item to the end of the list control.
         """
-        if 'append' in self.factory.operations:
+        if "append" in self.factory.operations:
             self.edit = True
             adapter = self.adapter
             index = self.control.GetItemCount()
@@ -787,9 +813,8 @@ class _ListStrEditor(Editor):
                     self.object,
                     self.name,
                     self.index,
-                    adapter.get_default_value(
-                        self.object,
-                        self.name))
+                    adapter.get_default_value(self.object, self.name),
+                )
 
     def _copy_current(self):
         """ Copies the currently selected list control item to the clipboard.
@@ -801,8 +826,9 @@ class _ListStrEditor(Editor):
                 try:
                     from pyface.wx.clipboard import clipboard
 
-                    clipboard.data = self.adapter.get_text(self.object,
-                                                           self.name, index)
+                    clipboard.data = self.adapter.get_text(
+                        self.object, self.name, index
+                    )
                 except:
                     # Handle the traits.util package not being installed by
                     # just ignoring the request:
@@ -813,7 +839,7 @@ class _ListStrEditor(Editor):
             in the clipboard.
         """
         ops = self.factory.operations
-        if ('insert' in ops) and ('delete' in ops):
+        if ("insert" in ops) and ("delete" in ops):
             selected = self._get_selected()
             if len(selected) == 1:
                 index = selected[0]
@@ -822,7 +848,8 @@ class _ListStrEditor(Editor):
                         from pyface.wx.clipboard import clipboard
 
                         clipboard.data = self.adapter.get_text(
-                            self.object, self.name, index)
+                            self.object, self.name, index
+                        )
                         self.index = index
                         self.adapter.delete(self.object, self.name, index)
                     except:
@@ -834,14 +861,15 @@ class _ListStrEditor(Editor):
         """ Pastes the clipboard contents into the currently selected list
             control item.
         """
-        if 'insert' in self.factory.operations:
+        if "insert" in self.factory.operations:
             selected = self._get_selected()
             if len(selected) == 1:
                 try:
                     from pyface.wx.clipboard import clipboard
 
-                    self._set_text_current(selected[0], clipboard.text_data,
-                                           insert=True)
+                    self._set_text_current(
+                        selected[0], clipboard.text_data, insert=True
+                    )
                 except:
                     # Handle the traits.util package not being installed by
                     # just ignoring the request:
@@ -850,7 +878,7 @@ class _ListStrEditor(Editor):
     def _insert_current(self):
         """ Inserts a new item after the currently selected list control item.
         """
-        if 'insert' in self.factory.operations:
+        if "insert" in self.factory.operations:
             selected = self._get_selected()
             if len(selected) == 1:
                 self.index = selected[0]
@@ -860,14 +888,13 @@ class _ListStrEditor(Editor):
                     self.object,
                     self.name,
                     selected[0],
-                    adapter.get_default_value(
-                        self.object,
-                        self.name))
+                    adapter.get_default_value(self.object, self.name),
+                )
 
     def _delete_current(self):
         """ Deletes the currently selected items from the list control.
         """
-        if 'delete' in self.factory.operations:
+        if "delete" in self.factory.operations:
             selected = self._get_selected()
             if len(selected) == 0:
                 return
@@ -883,7 +910,7 @@ class _ListStrEditor(Editor):
     def _move_up_current(self):
         """ Moves the currently selected item up one line in the list control.
         """
-        if 'move' in self.factory.operations:
+        if "move" in self.factory.operations:
             selected = self._get_selected()
             if len(selected) == 1:
                 index = selected[0]
@@ -899,7 +926,7 @@ class _ListStrEditor(Editor):
     def _move_down_current(self):
         """ Moves the currently selected item down one line in the list control.
         """
-        if 'move' in self.factory.operations:
+        if "move" in self.factory.operations:
             selected = self._get_selected()
             if len(selected) == 1:
                 index = selected[0]
@@ -915,7 +942,7 @@ class _ListStrEditor(Editor):
     def _edit_current(self):
         """ Allows the user to edit the current item in the list control.
         """
-        if 'edit' in self.factory.operations:
+        if "edit" in self.factory.operations:
             selected = self._get_selected()
             if len(selected) == 1:
                 self.control.EditLabel(selected[0])
@@ -924,20 +951,23 @@ class _ListStrEditor(Editor):
         """ Returns whether or not the index is the special 'auto add' item at
             the end of the list.
         """
-        return (self.factory.auto_add and
-                (index >= self.adapter.len(self.object, self.name)))
+        return self.factory.auto_add and (
+            index >= self.adapter.len(self.object, self.name)
+        )
 
     def _set_text_current(self, index, text, insert=False):
         """ Sets the text value of the specified list control item.
         """
-        if text.strip() != '':
+        if text.strip() != "":
             object, name, adapter = self.object, self.name, self.adapter
             if insert or self._is_auto_add(index):
-                adapter.insert(object, name, index,
-                               adapter.get_default_value(object, name))
-                self.edit = (not insert)
+                adapter.insert(
+                    object,
+                    name,
+                    index,
+                    adapter.get_default_value(object, name),
+                )
+                self.edit = not insert
 
             self.index = index + 1
             adapter.set_text(object, name, index, text)
-
-#--EOF-------------------------------------------------------------------------
