@@ -1,10 +1,10 @@
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 #  Copyright (c) 2006, Enthought, Inc.
 #  All rights reserved.
 #
 #  This software is provided without warranty under the terms of the BSD
-#  license included in enthought/LICENSE.txt and may be redistributed only
+#  license included in LICENSE.txt and may be redistributed only
 #  under the conditions described in the aforementioned license.  The license
 #  is also available online at http://www.enthought.com/licenses/BSD.txt
 #
@@ -13,38 +13,33 @@
 #  Author: David C. Morrill
 #  Date:   07/06/2006
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 
 """ Define an editor that displays a string value as a title.
 """
 
-#-------------------------------------------------------------------------
-#  Imports:
-#-------------------------------------------------------------------------
 
-from .editor \
-    import Editor
+from .editor import Editor
 
-from pyface.heading_text \
-    import HeadingText
+from pyface.heading_text import HeadingText
 
 # FIXME: TitleEditor (the editor factory for title editors) is a proxy class
 # defined here just for backward compatibility. The class has been moved to
 # traitsui.editors.title_editor.
-from traitsui.editors.title_editor \
-    import TitleEditor
+from traitsui.editors.title_editor import TitleEditor
 
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #  '_TitleEditor' class:
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
+
 
 class _TitleEditor(Editor):
 
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
     #  Finishes initializing the editor by creating the underlying toolkit
     #  widget:
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
 
     def init(self, parent):
         """ Finishes initializing the editor by creating the underlying toolkit
@@ -54,9 +49,9 @@ class _TitleEditor(Editor):
         self.control = self._control.control
         self.set_tooltip()
 
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
     #  Updates the editor when the object trait changes external to the editor:
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
 
     def update_editor(self):
         """ Updates the editor when the object trait changes external to the
