@@ -1,10 +1,10 @@
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #
 #  Copyright (c) 2005, Enthought, Inc.
 #  All rights reserved.
 #
 #  This software is provided without warranty under the terms of the BSD
-#  license included in enthought/LICENSE.txt and may be redistributed only
+#  license included in LICENSE.txt and may be redistributed only
 #  under the conditions described in the aforementioned license.  The license
 #  is also available online at http://www.enthought.com/licenses/BSD.txt
 #
@@ -13,7 +13,7 @@
 #  Author: David C. Morrill
 #  Date:   11/01/2004
 #
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 
 """ Creates a wizard-based wxPython user interface for a specified UI object.
 
@@ -21,35 +21,22 @@
     can navigate with forward and back buttons.
 """
 
-#-------------------------------------------------------------------------
-#  Imports:
-#-------------------------------------------------------------------------
 
 import wx
-import wx.wizard as wz
+import wx.adv as wz
 
-from .constants \
-    import DefaultTitle
+from traits.api import Str, Either
 
-from .helper \
-    import restore_window, save_window, GroupEditor
+from .constants import DefaultTitle
+from .helper import restore_window, save_window, GroupEditor
+from .ui_panel import fill_panel_for_group
 
-from .ui_panel \
-    import fill_panel_for_group
-
-from traits.api \
-    import Trait, Str
-
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #  Trait definitions:
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 
 # Trait that allows only None or a string value
-none_str_trait = Trait('', None, str)
-
-#-------------------------------------------------------------------------
-#  Creates a wizard-based wxPython user interface for a specified UI object:
-#-------------------------------------------------------------------------
+none_str_trait = Either(None, Str, default="")
 
 
 def ui_wizard(ui, parent):
@@ -57,15 +44,9 @@ def ui_wizard(ui, parent):
     object.
     """
     # Create the copy of the 'context' we will need while editing:
-    context = ui.context
-    ui._context = context
-    new_context = {}
-    for name, value in list(context.items()):
-        if value is not None:
-            new_context[name] = value.clone_traits()
-        else:
-            new_context[name] = None
-
+    ui._context = context = ui.context
+    new_context = {name: None if value is None else value.clone_traits()
+                   for name, value in context.items()}
     ui.context = new_context
 
     # Now bind the context values to the 'info' object:
@@ -73,7 +54,7 @@ def ui_wizard(ui, parent):
 
     # Create the wxPython wizard window:
     title = ui.view.title
-    if title == '':
+    if title == "":
         title = DefaultTitle
     ui.control = wizard = wz.Wizard(parent, -1, title)
 
@@ -99,7 +80,7 @@ def ui_wizard(ui, parent):
         # A simple solution is to clear out these fields before calling
         # "fill_panel_for_group", and then reset these traits.
         group_fields_mapping[group] = (group.id, group.enabled_when)
-        (group.id, group.enabled_when) = ('', '')
+        (group.id, group.enabled_when) = ("", "")
         page = UIWizardPage(wizard, editor_pages)
         pages.append(page)
         fill_panel_for_group(page, group, ui)
@@ -127,7 +108,7 @@ def ui_wizard(ui, parent):
     wizard.SetPageSize(wx.Size(min_dx, min_dy))
 
     # Set up the wizard 'page changing' event handler:
-    wz.EVT_WIZARD_PAGE_CHANGING(wizard, wizard.GetId(), page_changing)
+    wizard.Bind(wz.EVT_WIZARD_PAGE_CHANGING, page_changing)
 
     # Size the wizard and the individual pages appropriately:
     prev_page = pages[0]
@@ -159,7 +140,7 @@ def ui_wizard(ui, parent):
     if wizard.RunWizard(pages[0]):
         # If successful, apply the modified context to the original context:
         original = ui._context
-        for name, value in list(ui.context.items()):
+        for name, value in ui.context.items():
             if value is not None:
                 original[name].copy_traits(value)
             else:
@@ -169,15 +150,12 @@ def ui_wizard(ui, parent):
         ui.result = False
 
     # Clean up loose ends, like restoring the original context:
+    wizard.Unbind(wz.EVT_WIZARD_PAGE_CHANGING, handler=page_changing)
     save_window(ui)
     ui.finish()
     ui.context = ui._context
     ui._context = {}
 
-#-------------------------------------------------------------------------
-#  Handles the user attempting to change the current wizard page:
-#-------------------------------------------------------------------------
-
 
 def page_changing(event):
     """ Handles the user attempting to change the current wizard page.
@@ -190,77 +168,54 @@ def page_changing(event):
         new_page = page.GetPrev()
 
     # If the page has a disabled PageGroupEditor object, veto the page change:
-    if ((new_page is not None) and
-        (new_page.editor is not None) and
-            (not new_page.editor.enabled)):
+    if ((new_page is not None)
+            and (new_page.editor is not None)
+            and (not new_page.editor.enabled)):
         event.Veto()
 
         # If their is a message associated with the editor, display it:
         msg = new_page.editor.msg
-        if msg != '':
+        if msg != "":
             wx.MessageBox(msg)
 
-#-------------------------------------------------------------------------
-#  'UIWizardPage' class:
-#-------------------------------------------------------------------------
 
-
-class UIWizardPage(wz.PyWizardPage):
+class UIWizardPage(wz.WizardPage):
     """ A page within a wizard interface.
     """
-    #-------------------------------------------------------------------------
-    #  Initializes the object:
-    #-------------------------------------------------------------------------
 
     def __init__(self, wizard, pages):
-        wz.PyWizardPage.__init__(self, wizard)
+        super().__init__(wizard)
         self.next = self.previous = self.editor = None
         self.pages = pages
 
-    #-------------------------------------------------------------------------
-    #  Sets the next page after this one:
-    #-------------------------------------------------------------------------
-
     def SetNext(self, page):
         """ Sets the next page after this one.
         """
         self.next = page
 
-    #-------------------------------------------------------------------------
-    #  Sets the previous page before this one:
-    #-------------------------------------------------------------------------
-
     def SetPrev(self, page):
         """ Sets the previous page to this one.
         """
         self.previous = page
 
-    #-------------------------------------------------------------------------
-    #  Returns the next page after this one:
-    #-------------------------------------------------------------------------
-
     def GetNext(self):
         """ Returns the next page after this one.
         """
         editor = self.editor
-        if (editor is not None) and (editor.__next__ != ''):
-            next = editor.__next__
-            if next is None:
+        if (editor is not None) and (editor.next != ""):
+            next_ = editor.next
+            if next_ is None:
                 return None
             for page in self.pages:
-                if page.id == next:
+                if page.id == next_:
                     return page
-        return self.__next__
-
-    #-------------------------------------------------------------------------
-    #  Returns the previous page before this one:
-    #-------------------------------------------------------------------------
+        return self.next
 
     def GetPrev(self):
         """ Returns the previous page to this one.
         """
         editor = self.editor
-        if (editor is not None) and (editor.previous != ''):
+        if (editor is not None) and (editor.previous != ""):
             previous = editor.previous
             if previous is None:
                 return None
@@ -269,21 +224,18 @@ class UIWizardPage(wz.PyWizardPage):
                     return page
         return self.previous
 
-#-------------------------------------------------------------------------
-#  'PageGroupEditor' class:
-#-------------------------------------------------------------------------
-
 
 class PageGroupEditor(GroupEditor):
     """ Editor for a group, which displays a page.
     """
-    #-------------------------------------------------------------------------
-    #  Trait definitions:
-    #-------------------------------------------------------------------------
 
-    # ID of next page to display
+    # -------------------------------------------------------------------------
+    #  Trait definitions:
+    # -------------------------------------------------------------------------
+
+    #: ID of next page to display
     next = none_str_trait
-    # ID of previous page to display
+    #: ID of previous page to display
     previous = none_str_trait
-    # Message to display if user can't link to page
-    msg = Str
+    #: Message to display if user can't link to page
+    msg = Str()
